#include	<stdlib.h>
#include	"TMPM370.h"
#include	"ipdefine.h"
#include	"D_Para.h"
#include	"D_Driver.h"


/****************************************************************************************
 * Module   : H_Encoder
 *---------------------------------------------------------------------------------------
 * Function : 
 * Input    : none
 * Output   : none
 * Note     : 
 ****************************************************************************************/
void	H_Encoder(void)
{

	if((EN0->TNCR & 0x00001000) != 0){	/* Phase Z is detected */
		R_EnCnt = EN0->CNT;
	}

	/* Adjust Z-phase,0deg of electrical-angle  */
	R_theta_enc = (VAR16)((R_EnCnt * (( FIXPOINT_16 /(cEncPulseNum*cEncMultiple))*(cPole/2))) + ELE_DEG(180));

	if((EN0->TNCR & 0x00002000) != 0){	/* CW */
		if(R_EnCnt >= R_EnCnt1){
			R_EnCnt_dev = (VAR16)(R_EnCnt - R_EnCnt1);
		}else{
			R_EnCnt_dev = (VAR16)(cEncPulseNum*cEncMultiple + R_EnCnt - R_EnCnt1);
		}
	}else{										/* CCW */
		if(R_EnCnt1 >= R_EnCnt){
			R_EnCnt_dev = (VAR16)((R_EnCnt1 - R_EnCnt) * (-1));
		}else{
			R_EnCnt_dev = (VAR16)((cEncPulseNum*cEncMultiple + R_EnCnt1 - R_EnCnt) * (-1));
		}
	}

	R_EnCnt1 = R_EnCnt;

	/* moving average */
	R_EncCntdevAve = R_EnCnt_dev;
	R_omega_enc = (VAR16)(R_EncCntdevAve * (VAR16)(FIXPOINT_15 / ((cEncPulseNum*cEncMultiple)/(cPole/2)) / cCtrlPrd / cHz_MAX));


	if(R_command.F_comm_encoder == SET){
		if(R_command.F_comm_Edetect == CLEAR){
			R_omega_I.word = 0;
		}

		R_omega.word = R_omega_enc<<16;
		R_omega_I.word = R_omega_enc<<16;

		if(R_command.F_comm_theta == SET){
			if(R_command.F_comm_omega == SET){
				if((EN0->TNCR & 0x00001000) != 0){	/* Phase Z is detected */
					R_theta.word = R_theta_enc<<16;
				}else{
					R_theta.word += (R_omega_com.half[1] * (VAR32)(FIXPOINT_16*cHz_MAX*cCtrlPrd))<<1;
				}
			}else{
				R_theta.word += (R_omega_com.half[1] * (VAR32)(FIXPOINT_16*cHz_MAX*cCtrlPrd))<<1;
			}
		}else{
			if((EN0->TNCR & 0x00001000) != 0){		/* Phase Z is detected */
				R_theta.word = R_theta_enc << 16;
			}else{
				R_theta.word = R_theta_com << 16;
			}
		}

	}
}


/****************************************************************************************
 * Module   : D_Detect_Rotor_Position
 *---------------------------------------------------------------------------------------
 * Function : Detect motor position
 * Input    : R_Id,R_Iq,R_Vd,R_theta
 * Output   : R_omega,R_theta
 * Note     : 
 ****************************************************************************************/
static T_32Q31	R_Ed_I;
static T_32Q31	R_Ed_PI;
static T_32Q31	R_omega_calc;

void	D_Detect_Rotor_Position(void)
{
/*************************************************/
/* Voltage equation                              */
/* Vd = RId + LdpId - OMEGA-estLq + Ed        */
/*   (p = d/dt, IdConstant value -> pId = 0)   */
/*************************************************/
	if(R_command.F_comm_Edetect == SET){
		VAR32	R_R_temp32,R_LQ_temp32;
		VAR32	R_OmegaErr_temp32;

	/* R_Ed = R_Vd - cMotor_R*R_Id + R_omega*cMotor_Lq*R_Iq */
		/* Voltage drop of resistance */ /* V = R*I  */
		/* R_R_temp32 * cV_MAX = FIXPOINT_15 * cMotor_R * R_Id * cA_MAX */
		R_R_temp32 = ((VAR32)(FIXPOINT_15*cMotor_R*cA_MAX/cV_MAX)*(VAR32)R_Id)<<1;

		/* Voltage drop of inductance */ /* V = 2fL*I */
		/* R_LQ_temp32 * cV_MAX = FIXPOINT_15 * 2 * R_omega * cHz_MAX * cMotor_Lq / 1000 * R_Iq * cA_MAX */
		R_LQ_temp32 = (VAR16)(FIXPOINT_15*PAI2*cA_MAX*cHz_MAX*cMotor_Lq/1000/cV_MAX);
		R_LQ_temp32 = (((R_omega.half[1] * R_LQ_temp32)<<1)+cROUND_BIT15)>>16;	/* Q15*Q15=Q15 */
		R_LQ_temp32 = (R_LQ_temp32 * R_Iq)<<1;									/* Q15*Q15=Q31 */

		/* d-axis induced voltage */
		R_Ed = (T_16Q15)((R_Vd.word - R_R_temp32 + R_LQ_temp32 + cROUND_BIT15)>>16);

		/* Operation of speed */
		/* OMEGAest = OMEGAref - KEd */
		/* OmegaErr(I) * cHz_MAX = FIXPOINT_15 * cPosition_Ki * cCtrlPrd * R_Ed * cV_MAX */
		R_OmegaErr_temp32 = ((VAR32)(FIXPOINT_15*cPosition_Ki*cCtrlPrd*cV_MAX/cHz_MAX) * (VAR32)R_Ed)<<1;

		if(R_omega_com.half[1] >= 0 ){
			R_Ed_I.word =R_Ed_I.word-R_OmegaErr_temp32;
			//R_Ed_I.word =ssub32(R_Ed_I.word, R_OmegaErr_temp32);	// Saturation subtraction
		}else{
			R_Ed_I.word =R_Ed_I.word+R_OmegaErr_temp32;
			//R_Ed_I.word =sadd32(R_Ed_I.word, R_OmegaErr_temp32);	// Saturation addition
		}
		/* Speed integration value = Speed command value + Error I value */
		R_omega_I.word =R_omega_com.word+ R_Ed_I.word;
//		R_omega_I.word =sadd32(R_omega_com.word, R_Ed_I.word);	//  Saturation addition

		/* OmegaErr(P) * cHz_MAX = FIXPOINT_15 * cPosition_Kp * R_Ed * cV_MAX */
		R_OmegaErr_temp32 = ((VAR32)(FIXPOINT_15*cPosition_Kp*cV_MAX/cHz_MAX) * (VAR32)R_Ed)<<1;

		if(R_omega_com.half[1] >= 0 ){
			R_Ed_PI.word = R_Ed_I.word-R_OmegaErr_temp32;
//			R_Ed_PI.word = ssub32(R_Ed_I.word, R_OmegaErr_temp32);	// Saturation subtraction
		}else{
			R_Ed_PI.word =R_Ed_I.word+R_OmegaErr_temp32;
//			R_Ed_PI.word =sadd32(R_Ed_I.word, R_OmegaErr_temp32);	// Saturation addition
		}
		/* Speed calculation value = Speed command value + Error PI value */
		R_omega_calc.word = R_omega_com.word+R_Ed_PI.word;
//		R_omega_calc.word = sadd32(R_omega_com.word, R_Ed_PI.word);	// Saturation addition

		if(R_command.F_comm_omega == SET){
			R_omega.word = R_omega_calc.word;
		}else{
			R_omega.word = R_omega_com.word;
			R_omega_I.word = R_omega_com.word;
			R_Ed_I.word = 0;
			R_Ed_PI.word = 0;
		}
		/* Position estimation */
		if(R_command.F_comm_theta == SET){
			if(R_command.F_comm_encoder == CLEAR){
				/* THETAn = THETAn-1 + OMEGA * t */
				R_theta.word += (R_omega.half[1] * (VAR32)(FIXPOINT_16*cHz_MAX*cCtrlPrd))<<1;
				temp4=R_omega.half[1];
			}
		}else{
			R_theta.word = (VAR32)(R_theta_com<<16);
		}
	}
	else{
		R_Ed = 0;
		R_omega_I.word = 0;
	}
}


/****************************************************************************************
 * Module   : D_Control_Speed
 *---------------------------------------------------------------------------------------
 * Function : Speed control ( Caricurate q-axis current )
 * Input    : R_omega,R_omega_com
 * Output   : R_Id_ref,R_Iq_ref
 * Note     : 
 ****************************************************************************************/
;void	D_Control_Speed(void)
{

	/* Determination of R_Iq_ref */
	
	if(R_command.F_comm_current == SET){
		VAR32	R_Temp_PI;
		// Speed deviation 
		R_omega_dev = (VAR16)((R_omega_com.word-R_omega.word)>>16);
//		R_omega_dev = (VAR16)(ssub32(R_omega_com.word, R_omega.word)>>16);// Saturation subtraction

		//	R_Temp_PI * cA_MAX = FIXPOINT_15 * cSpeed_Ki * cCtrlPrd * R_omega_dev * cHz_MAX 
		R_Temp_PI = ((VAR32)(FIXPOINT_15*cSpeed_Ki*cCtrlPrd*cHz_MAX/cA_MAX) * R_omega_dev)<<1;

		R_Iq_ref_I.word =R_Iq_ref_I.word+R_Temp_PI;
//		R_Iq_ref_I.word = sadd32(R_Iq_ref_I.word, R_Temp_PI);// Saturation addition
		if(R_Iq_ref_I.word > (VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX)){
			R_Iq_ref_I.word = (VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX);
		}else if(R_Iq_ref_I.word < -(VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX)){
			R_Iq_ref_I.word = -(VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX);
		}

		//* Temp_PI * cA_MAX = FIXPOINT_15 * cSpeed_Kp * R_omega_dev * cHz_MAX 
		R_Temp_PI = ((VAR32)(cSpeed_Kp*FIXPOINT_15*cHz_MAX/cA_MAX) * R_omega_dev)<<1;

		R_Iq_ref = (T_16Q15)((R_Iq_ref_I.word+R_Temp_PI)>>16);//__SADD(R_Iq_ref_I.word, R_Temp_PI)>>16);
//		R_Iq_ref = (T_16Q15)(sadd32(R_Iq_ref_I.word, R_Temp_PI)>>16);// Saturation addition

		if( R_Iq_ref > (T_16Q15)(FIXPOINT_15*cIq_Lim/cA_MAX) ){
			R_Iq_ref = (T_16Q15)(FIXPOINT_15*cIq_Lim/cA_MAX);
		}else if( R_Iq_ref < -(T_16Q15)(FIXPOINT_15*cIq_Lim/cA_MAX) ){
			R_Iq_ref = -(T_16Q15)(FIXPOINT_15*cIq_Lim/cA_MAX);
		}

	}else{
		// Without Speed control. R_Iq_com -> R_Iq_ref 
		if(abs(R_Iq_com.word) >= (VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX)){
			if(R_Iq_com.word >= 0){
				R_Iq_ref = (T_16Q15)((VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX)>>16);
				R_Iq_ref_I.word = (VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX);
			}else{
				R_Iq_ref = -(T_16Q15)((VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX)>>16);
				R_Iq_ref_I.word = -(VAR32)(FIXPOINT_31*cIq_Lim/cA_MAX);
			}
		}else{
			R_Iq_ref = R_Iq_com.half[1];
			R_Iq_ref_I.word = R_Iq_com.word;
		}
	}

	//Determination of R_Id_ref  
	if(abs(R_Id_com.word) >= (VAR32)(FIXPOINT_31*cId_Lim/cA_MAX)){
		if(R_Id_com.word >= 0){
			R_Id_ref = (T_16Q15)((VAR32)(FIXPOINT_31*cId_Lim/cA_MAX)>>16);
		}else{
			R_Id_ref = -(T_16Q15)((VAR32)(FIXPOINT_31*cId_Lim/cA_MAX)>>16);
		}
	}else{
		R_Id_ref = R_Id_com.half[1];
	}
}


/***************************************************
    Serial data set for DAC output                 *
****************************************************/
void	Out_data(void)
{
//	while((SIO.cnl[1].IO_SCnMOD2 & 0x20)){}	// Wait to end of transmit
	R_DebugOut_Counter++;

	if(R_DebugOut_Counter >= 13){
		R_DebugOut_Counter = 13;
		PE->DATA |= 0x08;				// PE3=H

	}else if(R_DebugOut_Counter ==1){
		PE->DATA &= 0xF7;				// PE3=L
		DAC_data[0] = R_Iq_ref;
		DAC_data[1] = R_Id_ref;
		DAC_data[2] = R_theta.half[1];
		DAC_data[3] = R_theta_enc;
		SC1->BUF = 0x03;

	}else if(R_DebugOut_Counter ==2){
		SC1->BUF = DAC_data[3]/0x100;

	}else if(R_DebugOut_Counter ==3){
		SC1->BUF = DAC_data[3];

	}else if(R_DebugOut_Counter ==4){
		PE->DATA |= 0x08;				// PE3=H
		PE->DATA &= 0xF7;				// PE3=L
		SC1->BUF = 0x02;

	}else if(R_DebugOut_Counter ==5){
		SC1->BUF = DAC_data[2]/0x100;

	}else if(R_DebugOut_Counter ==6){
		SC1->BUF = DAC_data[2];

	}else if(R_DebugOut_Counter ==7){
		PE->DATA |= 0x08;				// PE3=H
		PE->DATA &= 0xF7;				// PE3=L
		SC1->BUF = 0x01;

	}else if(R_DebugOut_Counter ==8){
		SC1->BUF = DAC_data[1]/0x100;

	}else if(R_DebugOut_Counter ==9){
		SC1->BUF = DAC_data[1];

	}else if(R_DebugOut_Counter ==10){
		PE->DATA |= 0x08;				// PE3=H
		PE->DATA &= 0xF7;				// PE3=L
		SC1->BUF = 0x0;

	}else if(R_DebugOut_Counter ==11){
		SC1->BUF = DAC_data[0]/0x100;

	}else if(R_DebugOut_Counter ==12){
		SC1->BUF = DAC_data[0];
	}
}

