#include "TMPM370.h"

#ifndef _DEFINE_H
#define _DEFINE_H
#undef EXTERN
#ifdef DEFINE_APP
#define EXTERN
#else
#define EXTERN  extern
#endif

/*****************************************************************

	Define for Software & Hardware & Application seting

******************************************************************/



/******** For Motor **********************************************/

#define	MOTOR_OUTPUT	1			/* PWM output to motor 0:Disable, 1:Enable (for debug) */

#define	F_state_emg_H	R_state.bit.b0			/* 	0:normal, 1: Over voltage(hard) */
#define	F_state_emg_I	R_state.bit.b1			/* 	0:normal, 1: Over voltage(soft) */
#define	F_state_emg_DC	R_state.bit.b2			/* 	0:normal, 1: Over Vdc           */

#define	ELE_DEG(x)		(FIXPOINT_16*x/360)		/* Electric Angle */


/******** For MCU ************************************************/

/* Interruption leve define */
/* Not use level 1          */
#define INTPMD0Lv		0x04	/*  */
#define INTEMG0Lv		0x06	/*  */
#define INTAD0Lv		0x07	/*  */
#define INTENCLv		0x02	/*  */


/***  Serial Interfase (SIO)**************************************/
// Define the constant data for SCnCR
#define	cSCCR_Ini	BIT8(0,0,0,0,0,0,1,0)	/* Initial set */
/*	                     | | | | | | | |
	                     | | | | | | | +----; IOC(R/W)		Clock select at I/O Interface mode  {0:In, 1:Out}
	                     | | | | | | +------; SCLKS(R/W)	Active edge for SCLK input          {0:Up, 1:Down}
	                     | | | | | +--------; FERR(R)		Framing error flag 					{ 1: Error has occurred }
	                     | | | | +----------; PERR(R)		Parity error/underrun error flag	{ 1: Error has occurred }
	                     | | | +------------; OERR(R)		Overrun error flag					{ 1: Error has occurred }
	                     | | |              ;				Error bits are cleared to 0 when read.
	                     | | +--------------; PE(R/W)		Parity								{ 0: Enable, 1: Disable }
	                     | +----------------; EVEN(R/W)		Parity type							{ 0: Odd, 1: Even }
	                     +------------------; RB8(R)		Bit 8 of a received character
*/
// Define the constant data for SCnMOD0
#define	cSCMOD0_Ini	BIT8(0,0,0,0,0,0,0,1)
/*	                     | | | | | | | |
	                     | | | | | | +-+----; SC(R/W)		Serial clock (for UART)
	                     | | | | | |        ;				{ 00: Timer ch01:TB4OUT ch23:TB7OUT
	                     | | | | | |        ;				  01: Baud rate generator
	                     | | | | | |        ;				  10: Internal clock(fsys)
	                     | | | | | |        ;				  11: External clock(SCLK0 input) (for SIO2, SIO3 only) }
	                     | | | | +-+--------; SM(R/W)		Serial transfer mode
	                     | | | |            ;				{ 00: I/O  Interface mode (for SIO2, SIO3 only)
	                     | | | |            ;				  01: 7-bit UART mode
	                     | | | |            ;				  10: 8-bit UART mode
	                     | | | |            ;				  11: 9-bit UART mode }
	                     | | | +------------; WU(R/W)		Wake-up function	IF not 9bitUARTmode, don't care
	                     | | +--------------; RXE(R/W)		Receive control
	                     | |                ;				 { 0:Disable, 1: Enable }
	                     | +----------------; CTSE(R/W)		Handshake control for SIO2, SIO3 only
	                     +------------------; TB8(R/W)		Bit 8 of a transmitted character
*/
// Define the constant data for SCnMOD1
#define	cSCMOD1_Ini	BIT8(0,1,0,0,0,0,0,1)
/*	                     | | | | | | | |
	                     | | | | | | | +----; ---			Write 0
	                     | | | | +-+-+------; SINT (R/W)    Interval time at series transmission
	                     | | | |            ; 				{ 000:non,   001:1SCLK,  010:2SCLK,  011:4SCLK  }
	                     | | | |            ; 				{ 100:8SCLK, 101:16SCLK, 110:32SCLK, 001:64SCLK }
	                     | | | +------------; TXE  (R/W)	Transmit E/D  { 0:Disable, 1:Enable }
	                     | | |              ;               *This bit is set after other set)
	                     | +-+--------------; FDPX(R/W)		Transmit mode
	                     |                  ;				{00:Prohibition 01:receve only 10:transe only 11:Both}
	                     +------------------; I2SO(R/W)		Mode at IDLE {0:STOP, 1:RUN}
*/
// Define the constant data for SCnMOD2
#define	cSCMOD2_Ini	BIT8(0,0,0,0,1,0,0,0)
/*	                     | | | | | | | |
	                     | | | | | | | |
	                     | | | | | | +-+----; SWRST(W)		Software reset		A write of "10" followed by a write of "01".
	                     | | | | | +--------; WBUF(R/W)		Double-buffering	{ 0: Disable, 1: Enable }
	                     | | | | +----------; DRCHG(R/W)	Bit sequence		{ 0: LSB first, 1: MSB first }
	                     | | | +------------; SBLEN(R/W)	Number of stop bits	{ 0: 1bit, 1:2bits }
	                     | | +--------------; TXRUN(R)		Transmit-in-progress flag	{ 0: Stopped, 1: Transmitting }
	                     | +----------------; RBFLL(R)		Receive buffer full flag	{ 0: Empty, 1: Full }
	                     +------------------; TBEMP(R)		Transmit buffer empty flag	{ 0: Full, 1: Empty }
*/

// Define the constant data for SCnBRCR & SCnBRADD for baud rate generator
//#define	cSCBRCR_Ini		BIT8(0,0,0,0,1,0,1,0);		// 1/16 disable T0 N=10  Set 229885bps<>230400bps
//#define	cSCBRCR_Ena		BIT8(0,1,0,0,1,0,1,0);		// 1/16 disable T0 N=10  Set 229885bps<>230400bps
//#define	cSCBRADD_Ini	BIT8(0,0,0,0,0,0,1,0);		//                 K=2       @fc, fper=80MHz

//#define	cSCBRCR_Ini		BIT8(0,0,0,0,0,0,1,0);		// 1/16 K-disable T0 N=2  Set 1250000bps for UART
//#define	cSCBRCR_Ena		BIT8(0,0,0,0,0,0,1,0);		// 1/16 K-disable T0 N=2  Set 1250000bps for UART
//#define	cSCBRADD_Ini	BIT8(0,0,0,0,0,0,0,0);		//             K=unuse      @fc, fper=80MHz
#define	cSCBRCR_Ini		BIT8(0,0,0,0,0,0,1,1);			// 1/16 K-disable T0 N=7 at IO mode
#define	cSCBRCR_Ena		BIT8(0,0,0,0,0,0,1,1);			// 1/16 K-disable T0 N=7 at IO mode
#define	cSCBRADD_Ini	BIT8(0,0,0,0,0,0,0,0);			//                 K=unuse      @fc, fper=80MHz



// Define the constant data for SCnFCNF
#define	cSCFCNF_Ini	BIT8(0,0,0,0,1,0,0,0)
/*	                     | | | | | | | |
	                     | | | | | | | +----; CNFG(R/W)		FIFO				{ 0:Disable 1:Enable }
                         | | | | | | +------; RXTXCNT(R/W)	Auto stop when FIFO empty/full { 0: Disable, 1: Enable }
	                     | | | | | +--------; RFIE(R/W)		INTRX at FIFO full  { 0: Disable 1:Enable }
	                     | | | | +----------; TFIE(R/W)		INTTX at FIFO empty { 0: Disable 1:Enable }
	                     | | | +------------; RFST(R/W)		FIFO size      { 0:MAX, 1:RLI value }
	                     | | +--------------; ---(R)		0
	                     | +----------------; ---(R)		0
	                     +------------------; ---(R)		0
*/
// Define the constant data for SCnRFC
#define	cSCRFC_Ini	BIT8(0,0,0,0,0,0,0,0)
/*	                     | | | | | | | |
	                     | | | | | | +-+----; RIL(R/W)		FIFO level of INTRX generate
                         | | | | | |        ; 				{ 00:4byte 01:1byte 10:2byte 11:3byte }
	                     | | +-+-+-+--------; ---(R)		0
	                     | |                ; ---(R)		0
	                     | |                ; ---(R)		0
	                     | |                ; ---(R)		0
	                     | +----------------; RFIS(R/W)		INTRX level {0:fill level 1:over fill level }
	                     +------------------; RFCS(W)		RXD FIFO clr { 0:NON 1:CLR }
*/
// Define the constant data for SCnTFC
#define	cSCTFC_Ini	BIT8(1,0,0,0,0,0,0,0)
/*	                     | | | | | | | |
	                     | | | | | | +-+----; TIL(R/W)		FIFO level of INTTX generate
                         | | | | | |        ; 				{ 00:4byte 01:1byte 10:2byte 11:3byte }
	                     | | +-+-+-+--------; ---(R)		0
	                     | |                ; ---(R)		0
	                     | |                ; ---(R)		0
	                     | |                ; ---(R)		0
	                     | +----------------; TFIS(R/W)		INTTX level { 0:fill level 1:over fill level }
	                     +------------------; TFCS(W)		TXD FIFO clr { 0:NON 1:CLR }
*/
// Define the constant data for SCnRST
#define	cSCRST_Ini	BIT8(0,0,0,0,0,0,0,0)
/*	                     | | | | | | | |
	                     | | | | | +-+-+----; RLVL(R)		RX FIFO level
                         | | | | |          ; 				{ 000:Empty 001:1byte 010:2byte 011:3byte }
                         | | | | |          ; 				  100:4byte }
	                     | +-+-+-+----------; ---(R)		0
	                     |                  ; ---(R)		0
	                     |                  ; ---(R)		0
	                     |                  ; ---(R)		0
	                     +------------------; RFCS(W)		RXD FIFO overrun { 1:Over run }
*/
// Define the constant data for SCnTST
#define	cSCTST_Ini	BIT8(0,0,0,0,0,0,0,0)
/*	                     | | | | | | | |
	                     | | | | | +-+-+----; TLVL(R)		TX FIFO level
                         | | | | |          ; 				{ 000:Empty 001:1byte 010:2byte 011:3byte }
                         | | | | |          ; 				  100:4byte }
	                     | +-+-+-+----------; ---(R)		0
	                     |                  ; ---(R)		0
	                     |                  ; ---(R)		0
	                     |                  ; ---(R)		0
	                     +------------------; TFCS(W)		TXD FIFO underrun { 1:Under run }
*/

/***  ENCODER    ****************************************************************************************/
// Define the constant data for ENxTNCR3
#define		cENTN_Init3	    BIT8(0,0,0,0,0,0,0,0)	/* Initial set */
						/*  	 | | | | | | | +--	Select phase at sensore mode 0:2ph, 1:3ph		*/
						/* 1	 | | | | | +-+----	Encoder input mode			   11:Timer			*/
						/* 2	 | | | | | 			00:Encoder 01:Sensor(Event CT) 10:Sensor(Timer)	*/
						/* 3	 | | | | +--------	0												*/
						/* 4	 | | | +----------	0												*/
						/* 5	 | | +------------	0												*/
						/* 6	 | +--------------	0												*/
						/* 7	 +----------------	0												*/

// Define the constant data for ENxTNCR0,1
#define		cENTN_Init0	  BIT16(0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0)	/* Initial set	 					 */
						/* 0	| | | | | | | | | | | | | +-+-+--	Divider of encoder puls	 			 */
						/* 1	| | | | | | | | | | | | | 			 000:/1  001:/2  010:/4  011:/8		 */
						/* 2	| | | | | | | | | | | | | 			 100:/16 101:/32 110:/64 111:/128	 */
						/* 3	| | | | | | | | | | | | +--------	Interrupt E/D  0:Disable  1:Enable	 */
						/* 4	| | | | | | | | | | +-+----------	Noise Filter	00:Non   01:31/PH	 */
						/* 5	| | | | | | | | | | 								10:63/PH 11:127/PH	 */
						/* 6	| | | | | | | | | +--------------	Encode E/D  0:Disable  1:Enable		 */
						/* 7	| | | | | | | | +----------------	Z phase  0:Disable  1:Enable		 */
						/* 8	| | | | | | | +------------------	CMPR E/D 0:Disable 1:Enable			 */
						/* 9	| | | | | | +--------------------	Egde select of Z signal 0:Up 1:Down	 */
						/*10	| | | | | +----------------------	  1: Counter clear					 */
						/*11	| | | | +------------------------	  1: Soft capture					 */
						/*12	| | | +--------------------------	R 1:Z signal						 */
						/*13	| | +----------------------------	R Direction 0:CCW 1:CW				 */
						/*14	| +------------------------------	R 1:Err								 */
						/*15	+--------------------------------	R 1:CMPR							 */
#define		cENTN_Init	(cENTN_Init3<<16) + cENTN_Init0


/***  CG    *********************************************************************************************/
// Define the constant data for SYSCR0: Select Clock Gear for system clock
#define		cCG_Init	   BIT8(0,0,0,0,0,0,0,0)	/* Initial 80MHz@10MHz */
#define		cCG_HALF	   BIT8(0,0,0,0,0,0,0,1)	/*         40MHz@10MHz */
						/* 0	| | | | | | | +--	000: fc   100: fc/2  101: fc/4					*/
						/* 1	| | | | | | +----	110: fc/8 111: fc/16 101: fc/32					*/
						/* 2	| | | | | +------	110: Reserved  111: Reserved					*/
						/* 3	| | | | +--------	0												*/
						/* 4	| | | +----------	0												*/
						/* 5	| | +------------	0												*/
						/* 6	| +--------------	0												*/
						/* 7	+----------------	0												*/

// Define the constant data for SYSCR1: Select Prescaler for timer & SIO
#define		cPRI_Init	   BIT8(0,0,0,0,0,0,0,0)	/* fperiph / 1 */
#define		cPRI_HALF	   BIT8(0,0,0,0,0,0,0,1)	/* fperiph / 2 */
						/* 0	| | | | | | | +--	000: fperiph   001: fperiph/2  010: fperiph/4	*/
						/* 1	| | | | | | +----	011: fperiph/8 100: fperiph/16 101: fperiph/32	*/
						/* 2	| | | | | +------	110: Reserved  111: Reserved					*/
						/* 3	| | | | +--------	0												*/
						/* 4	| | | +----------	Select souce clock for Periferal  0:fc 1:fsys	*/
						/* 5	| | +------------	0												*/
						/* 6	| +--------------	0												*/
						/* 7	+----------------	0												*/


#define	cSYSCR_Init		(uint32_t)(cPRI_Init<<8 | cCG_Init)	
#define	cSYSCR_HALF		(uint32_t)(cPRI_HALF<<8 | cCG_HALF)	


// Define the constant data for OSCCR0: Select Oscirator set 0
#define		cOSC0_Init	   BIT8(0,0,0,0,0,0,0,0)	/* OSCCR0 Initial								*/
						/* 0	| | | | | | | +--	Warming up timer  1:start						*/
						/* 1	| | | | | | +----	Monitor of Warming up 0:END 1:counting			*/
						/* 2	| | | | | +------	PLL ON/OFF  0:STOP  1:START						*/
						/* 3	| | | | +--------	0												*/
						/* 4	| | | +----------	0												*/
						/* 5	| | +------------	0												*/
						/* 6	| +--------------	0												*/
						/* 7	+----------------	0												*/

// Define the constant data for OSCCR1: Select Oscirator set 1
#define		cOSC1_Init0	   BIT8(0,0,0,0,0,0,0,1)	/* OSCCR0 Initial								*/
						/* 0	| | | | | | | +--	High speed OSC E/D 0:Disable, 1*Enable			*/
						/* 1	| | | | | | +----	0												*/
						/* 2	| | | | | +------	0									q			*/
						/* 3	| | | | +--------	0												*/
						/* 4	| | | +----------	High speed OSC current 0:Large, 1:Small			*/
						/* 5	| | +------------	0												*/
						/* 6	| +--------------	0												*/
						/* 7	+----------------	0												*/

// Define the constant data for OSCCR2: Select Oscirator set 2
#define		cOSC2_Init0	   BIT8(0,0,0,0,0,1,0,1)	/* OSCCR2 Initial								*/
						/* 0	| | | | | | | +--	Internal OSC E/D 0:Disable, 1*Enable			*/
						/* 1	| | | | | | +----	High speed OSC select 0:Internal  1:External	*/
						/* 2	| | | | | +------	PORT 0:I/O, 1:OSC 								*/
						/* 3	| | | | +--------	Warming up 2 0:Internal ,1:External				*/
						/* 4	| | | +----------	High speed OSC current 0:Large, 1:Small			*/
						/* 5	| | +------------	0												*/
						/* 6	| +--------------	0												*/
						/* 7	+----------------	0												*/

// Define the warming up timer data (14bit)
#define		cWU_Init		0x80	// (128 count)

// Define the OSCCR1 Inisial (8bit)
#define		cOSC1_Init	cOSC1_Init0 + ((cWU_Init<<6) & 0xC0)

// Define the OSCCR2 Inisial (8bit)
#define		cOSC2_Init	cOSC2_Init0 + ((cWU_Init<<2) & 0xF0)

// Define the OSCCR3 Inisial (8bit)
#define		cOSC3_Init	(cWU_Init>>6) & 0x0000FF


#define cOSC_Init	(uint32_t)(cOSC3_Init<<24 | cOSC2_Init<<16 |cOSC1_Init<<8 |cOSC0_Init)



// Define the STBYCR0 ~ 2 : Setting og Stand-by mode
#define		cSTBYCR0_Init	0x00					// The mode of Stand-by 001:STOP, 011:IDOL
#define		cSTBYCR1_Init	0x01					// After stop OSC condition 0:STOP 1:START
#define		cSTBYCR2_Init	0x00					// Port drive at STOP mode 0:Non 1:Drive

// Define the PLLSEL : Select PLL ON/OFF
#define		cPLLSEL_Init	0xA13E					// PLL init & fosc
#define		cPLLSEL_fpll	0xA13F					// PLL out fpll
#define		cOSC0_PLLON		(cOSC0_Init | 0x04)		// bit2=1 PLLON
#define		cOSC2_EOSC		(cOSC2_Init | 0x02)		// bit1=1 H-Speed is External OSC
#define		cCKSEL_Init		0x00					// unknown reg ?


/***  PMD   *********************************************************************************************/
// Define the constant data for MDEN
#define		PMD0_Enable		PMD0->MDEN = 1		// PMD0 Enable
#define		PMD0_Disable	PMD0->MDEN = 0		// PMD0 Disable
#define		PMD1_Enable		PMD1.IO_MDEN = 1		// PMD1 Enable
#define		PMD1_Disable	PMD1.IO_MDEN = 0		// PMD1 Disable

// Define the constant data for MODESEL
#define		WBUF_BUS	0							// W-BUF data from Bus (by software)
#define		WBUF_VE		1							// W-BUF data from VE (automatic)

// Define the constant data for MDCR
#define		cMDCR_INI	   BIT8(0,0,0,1,0,0,1,1)	/* Initial set */
//#define	cMDCR_INI	   BIT8(0,0,0,1,1,0,1,1)	/* Initial set */
						/* 0	| | | | | | | +--	PWMMD PWM mode  0:Edage PWM, 1:Center PWM		*/
						/* 1	| | | | | +-+----	INTPRD INTPWM timing   00: half PWM				*/
						/* 2	| | | | |			  01: 1cycle, 10: 2cycle 11: 4cycle				*/
						/* 3	| | | | +--------	PINT INTPWM timing 0:CNT=1, 1:CNT=MDPRD			*/
						/* 4	| | | +----------	DTYMD Duty mode 0:U phase set only, 1: 3phase	*/
						/* 5	| | +------------	SYNTMD Special PWM mode  0:normal, 1:special	*/
						/* 6	| +--------------	PWMCK  Divide PWM clock  0:normal, 1:1/4		*/
						/* 7	+----------------	0												*/

// Define the constant data for MDOUT
// cMDOUT_ON1~3 for change polarity of 1 shunt.
#define		cMDOUT_OFF	  BIT16(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)	/* OUTPUT all L */
#define		cMDOUT_ON	  BIT16(0,0,0,0,0,1,1,1,0,0,1,1,1,1,1,1)	/* OUTPUT all PWM/~PWM */
#define		cMDOUT_ON1	  BIT16(0,0,0,0,0,1,1,1,0,0,1,1,0,0,1,1)	/* OUTPUT PWM/~PWM except V (~PWM/PWM) */
#define		cMDOUT_ON2	  BIT16(0,0,0,0,0,1,1,1,0,0,0,0,1,1,1,1)	/* OUTPUT PWM/~PWM except W (~PWM/PWM) */
#define		cMDOUT_ON3	  BIT16(0,0,0,0,0,1,1,1,0,0,1,1,1,1,0,0)	/* OUTPUT PWM/~PWM except U (~PWM/PWM) */
#define		cMDOUT_ON4	  BIT16(0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0)	/* OUTPUT ~PWM/PWM */
						/* 0	| | | | | | | | | | | | | | | +--	UOC X out 0:OFF 1:ON	*/
						/* 1	| | | | | | | | | | | | | | +----	    U out 0:OFF 1:ON	*/
						/* 2	| | | | | | | | | | | | | +------	VOC Y out 0:OFF 1:ON	*/
						/* 3	| | | | | | | | | | | | +--------	    V out 0:OFF 1:ON	*/
						/* 4	| | | | | | | | | | | +----------	WOC Z out 0:OFF 1:ON	*/
						/* 5	| | | | | | | | | | +------------	    W out 0:OFF 1:ON	*/
						/* 6	| | | | | | | | | +--------------	0						*/
						/* 7	| | | | | | | | +----------------	0						*/
						/* 8	| | | | | | | +------------------	UPWM U out 0:H/L 1:PWM	*/
						/* 9	| | | | | | +--------------------	UPWM U out 0:H/L 1:PWM	*/
						/*10	| | | | | +----------------------	UPWM U out 0:H/L 1:PWM	*/
						/*11	| | | | +------------------------	0						*/
						/*12	| | | +--------------------------	0						*/
						/*13	| | +----------------------------	0						*/
						/*14	| +------------------------------	0						*/
						/*15	+--------------------------------	0						*/

/* Motor output MDOUT,MDPOT  M370%% */
#define		MOTOR_OUTPUT_OFF			PMD0->MDPOT = cMDPOT_OFF; \
										PMD0->MDOUT = cMDOUT_OFF
#define		MOTOR_OUTPUT_ON				PMD0->MDPOT = cMDPOT_ON; \
										PMD0->MDOUT = cMDOUT_ON
#define		MOTOR_OUTPUT_ON1			PMD0->MDPOT = cMDPOT_ON1; \
										PMD0->MDOUT = cMDOUT_ON1
#define		MOTOR_OUTPUT_ON2			PMD0->MDPOT = cMDPOT_ON2; \
										PMD0->MDOUT = cMDOUT_ON2
#define		MOTOR_OUTPUT_ON3			PMD0->MDPOT = cMDPOT_ON3; \
										PMD0->MDOUT = cMDOUT_ON3
#define		MOTOR_OUTPUT_ON4			PMD0->MDPOT = cMDPOT_ON4; \
										PMD0->MDOUT = cMDOUT_ON4

/* Motor output CMPx M370%% */
#define		SET_DUTY_U_PHASE(x)			PMD0->CMPU = x
#define		SET_DUTY_V_PHASE(x)			PMD0->CMPV = x
#define		SET_DUTY_W_PHASE(x)			PMD0->CMPW = x

// Define the constant data for MDPOT
#define		cMDPOT_OFF	   BIT8(0,0,0,0,1,1,0,0)	/* OUTPUT all L */
#define		cMDPOT_ON	   BIT8(0,0,0,0,1,1,1,1)	/* OUTPUT all PWM/~PWM */
#define		cMDPOT_ON1	   BIT8(0,0,0,0,1,1,1,1)	/* OUTPUT PWM/~PWM except V (~PWM/PWM) */
#define		cMDPOT_ON2	   BIT8(0,0,0,0,1,1,1,1)	/* OUTPUT PWM/~PWM except W (~PWM/PWM) */
#define		cMDPOT_ON3	   BIT8(0,0,0,0,1,1,1,1)	/* OUTPUT PWM/~PWM except U (~PWM/PWM) */
#define		cMDPOT_ON4	   BIT8(0,0,0,0,1,1,1,0)	/* OUTPUT ~PWM/PWM */
						/* 0	| | | | | | +-+--	PSYNCS MDOUT reloard timing		00:unsyncronus,	*/
						/* 1	| | | | | | 		  01:CNT=1, 10:CNT=MDPRD, 11:CNT= 1 or MDPRD	*/
						/* 2	| | | | | +------	POLL Low  phase Tr active 0:L act, 1:H act		*/
						/* 3	| | | | +--------	POLH High phase Tr active 0:L act, 1:H act		*/
						/* 4	| | | +----------	0												*/
						/* 5	| | +------------	0												*/
						/* 6	| +--------------	0												*/
						/* 7	+----------------	0												*/

// Define the constant data for TRGCR
#define		cTRG_1SHUNT0  BIT16(0,0,0,0,0,1,0,0,1,0,0,1,1,0,0,1)	/* 1shunt (TRG0:Down,TRG1:Down,TRG2:Peek */
#define		cTRG_1SHUNT1  BIT16(0,0,0,0,0,1,0,0,1,0,1,0,1,0,0,1)	/* 1shunt (TRG0:Down,TRG1:UP,TRG3:Peek   */
#define		cTRG_3SHUNT	  BIT16(0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0)	/* 3shunt (TRG0:Peek) 					*/
						/* 0	| | | | | | | | | | | | | | | +--	| TRG0MD Trigger position 				*/
						/* 1	| | | | | | | | | | | | | | +----	| 	000,111:Dis, 001:Down, 010:Up		*/
						/* 2	| | | | | | | | | | | | | +------	|	011:U/D,100:Peek,101:Bot,110:P/B	*/
						/* 3	| | | | | | | | | | | | +--------	  TRG0BE Timming of renewal of TRGCMPx	*/
						/* 		| | | | | | | | | | | | +					 0:Soon,1:Synchronizes PWM		*/
						/* 4	| | | | | | | | | | | +----------	| TRG1MD								*/
						/* 5	| | | | | | | | | | +------------	|										*/
						/* 6	| | | | | | | | | +--------------	|										*/
						/* 7	| | | | | | | | +----------------	  TRG1BE								*/
						/* 8	| | | | | | | +------------------	| TRG2MD								*/
						/* 9	| | | | | | +--------------------	|										*/
						/*10	| | | | | +----------------------	|										*/
						/*11	| | | | +------------------------	  TRG2BE								*/
						/*12	| | | +--------------------------	| TRG3MD								*/
						/*13	| | +----------------------------	|										*/
						/*14	| +------------------------------	|										*/
						/*15	+--------------------------------	  TRG3BE								*/


// Define the constant data for EMGCR
#define		cEMG_ENA	  BIT16(0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,1)	/* Enable EMG	*/
#define		cEMG_DIS	  BIT16(0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0)	/* Disable EMG	*/
#define		cEMG_Release  BIT16(0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0)	/* Release EMG	*/
						/* 0	| | | | | | | | | | | | | | | +--	EMGEN EMG Enable  0:Disable 1:Enable	*/
						/* 1	| | | | | | | | | | | | | | +----	EMGRS 0:-, 1:Release from EMG			*/
						/* 2	| | | | | | | | | | | | | +------	EMGISEL Sourse of EMG 0:port, 1:CMP		*/
						/* 3	| | | | | | | | | | | | +--------	EMGMD Stop mode 00:Not stop output		*/
						/* 4	| | | | | | | | | | | +----------		01:XYZ OFF, 10:UVW OFF, 11:all OFF	*/
						/* 5	| | | | | | | | | | +------------	INHEN Tool Break 0:Disable, 1:Enable	*/
						/* 6	| | | | | | | | | +--------------	0								*/
						/* 7	| | | | | | | | +----------------	0								*/
						/* 8	| | | | | | | +------------------	EMGCNT	Detection counter 4bit	*/
						/* 9	| | | | | | +--------------------	  base clock 16/fx				*/
						/*10	| | | | | +----------------------									*/
						/*11	| | | | +------------------------									*/
						/*12	| | | +--------------------------	0								*/
						/*13	| | +----------------------------	0								*/
						/*14	| +------------------------------	0								*/
						/*15	+--------------------------------	0								*/

// Define the constant data for OVVCR
#define		cOVV_ENA	  BIT16(0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,1)	/* Enable OVV  */
#define		cOVV_DIS	  BIT16(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)	/* Disable OVV */
#define		cOVV_Release0 BIT16(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)	/* Release OVV setting 0 (1st)	 */
#define		cOVV_Release1 BIT16(0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0)	/* Release OVV setting 1 (2nd)	 */
						/* 0	| | | | | | | | | | | | | | | +--	OVVEN OVV Enable  0:Disable 1:Enable	*/
						/* 1	| | | | | | | | | | | | | | +----	OVVRS auto release 0:Dis, 1:Ena			*/
						/* 2	| | | | | | | | | | | | | +------	OVVISEL Sourse of OVV 0:port, 1:ADC		*/
						/* 3	| | | | | | | | | | | | +--------	OVVMD Stop mode 00:Not stop output		*/
						/* 4	| | | | | | | | | | | +----------		01:XYZ OFF, 10:UVW OFF, 11:all OFF	*/
						/* 5	| | | | | | | | | | +------------	ADIN0EN AD0 watch input 0:Dis, 1:Ena	*/
						/* 6	| | | | | | | | | +--------------	ADIN1EN AD1 watch input 0:Dis, 1:Ena	*/
						/* 7	| | | | | | | | +----------------	0								*/
						/* 8	| | | | | | | +------------------	OVVCNT	Detection counter 4bit	*/
						/* 9	| | | | | | +--------------------	  base clock 16/fx				*/
						/*10	| | | | | +----------------------									*/
						/*11	| | | | +------------------------									*/
						/*12	| | | +--------------------------	0								*/
						/*13	| | +----------------------------	0								*/
						/*14	| +------------------------------	0								*/
						/*15	+--------------------------------	0								*/

/* EMG check */
#define		CHECK_EMG0_STATE			(PMD0->EMGSTA & 0x01)		// Check EMG State
#define		CHECK_EMG0_PORT				(PMD0->EMGSTA & 0x02)		// Check EMG input level
#define		RELEASE_EMG0_STATE			PMD0->EMGREL = cEMG_Release

/* OVV check */
#define		CHECK_OVV0_STATE			(PMD0->OVVSTA & 0x01)		// Check OVV State
#define		CHECK_OVV0_PORT				(PMD0->OVVSTA & 0x02)		// Check OVV input
#define		RELEASE_OVV0_STATE			PMD0->OVVREL = cOVV_Release


/***********************VE Control Register*************************/
#define ioMODEREGIn		0x3		// Use VE:0x3, Un-use VE:0x0

//#define ioVEENIn		0x1
//R:READ,W:WRITE
#define	ioVEENIn		0x1		// RW
//#define	ioCPURUNTRGIn	0x0	// W
#define	ioTASKAPPIn		0x0		// RW
#define	ioACTSCHIn		0x9		// RW
#define	ioREPTIMEIn		0x1		// RW
#define	ioTRGMODEIn		0x0		// RW
#define	ioERRINTENIn	0x1		// RW
#define	ioCOMPENDIn		0x0		// W
#define	ioERRDETIn		0x0		// R
#define	ioSCHTASKRUNIn	0x0		// R
#define	ioTMPREG0In		0x0		// RW
#define	ioTMPREG1In		0x0		// RW
#define	ioTMPREG2In		0x0		// RW
#define	ioTMPREG3In		0x0		// RW
#define	ioTMPREG4In		0x0		// RW
#define	ioTMPREG5In		0x0		// RW

#define	ioCPURUNTRGIn	0x1		// W
/***********************VE Register for Channel 0*********************/

#define	ioMCTLF0In		0x0		// RW
#define	ioMODE0In		0x0		// RW
#define	ioFMODE0In		0x0		// RW
#define	ioTPWM0In		(UVAR16)(65536*cHz_MAX*0.000125)		//	RW
#define	ioOMEGA0In		0x0		// RW R_omega.half[1]
#define	ioTHETA0In		0x0		// RW R_theta.half[1]
#define	ioIDREF0In		0x0		// RW R_Id_ref
#define	ioIQREF0In		0x0		// RW R_Iq_ref
#define	ioVD0In			0x0		// RW R_Vd.word
#define	ioVQ0In			0x0		// RW R_Vq.word
#define	ioCIDKI0In		0x0		// RW
#define	ioCIDKP0In		0x0		// RW
#define	ioCIQKI0In		0x0		// RW
#define	ioCIQKP0In		0x0		// RW
#define	ioVDIH0In		0x0		// RW
#define	ioVDILH0In		0x0		// RW
#define	ioVQIH0In		0x0		// RW
#define	ioVQILH0In		0x0		// RW
#define	ioFPWMCHG0In	0x0		// RW
#define	ioVMDPRD0In				// RW
#define	ioMINPLS0In		0x0		// RW
#define	ioTRGCRC0In		0x0		// RW
#define	ioVDCL0In		(T_16Q15)(FIXPOINT_15*cVdc_Lim/cV_MAX)		//	RW
#define	ioCOS0In		0x0		// RW
#define	ioSIN0In		0x0		// RW
#define	ioCOSM0In		0x0		// RW
#define	ioSINM0In		0x0		// RW
#define	ioSECTOR0In		0x0		// RW R_Sector
#define	ioSECTORM0In	0x0		// RW
#define	ioIAO0In		0x0		// RW R_Iao
#define	ioIBO0In		0x0		// RW R_Ibo
#define	ioICO0In		0x0		// RW R_Ico
#define	ioIAADC0In		0x0		// RW R_Ia_adc
#define	ioIBADC0In		0x0		// RW R_Ib_adc
#define	ioICADC0In		0x0		// RW R_Ic_adc
#define	ioVDC0In		0x0		// RW R_Vdc
#define	ioID0In			0x0		// RW R_Id.word
#define	ioIQ0In			0x0		// RW R_Iq.word

/***********************VE Register for Channel 1*********************/
#define	ioMCTLF1In		0x0		// RW
#define	ioMODE1In		0x0		// RW
#define	ioFMODE1In		0x0		// RW
#define	ioTPWM1In		0x0		// RW
#define	ioOMEGA1In		0x0		// RW
#define	ioTHETA1In		0x0		// RW
#define	ioIDREF1In		0x0		// RW
#define	ioIQREF1In		0x0		// RW
#define	ioVD1In			0x0		// RW
#define	ioVQ1In			0x0		// RW
#define	ioCIDKI1In		0x0		// RW
#define	ioCIDKP1In		0x0		// RW
#define	ioCIQKI1In		0x0		// RW
#define	ioCIQKP1In		0x0		// RW
#define	ioVDIH1In		0x0		// RW
#define	ioVDILH1In		0x0		// RW
#define	ioVQIH1In		0x0		// RW
#define	ioVQILH1In		0x0		// RW
#define	ioFPWMCHG1In	0x0		// RW
#define	ioVMDPRD1In		0x0		// RW
#define	ioMINPLS1In		0x0		// RW
#define	ioTRGCRC1In		0x0		// RW
#define	ioVDCL1In		0x0		// RW
#define	ioCOS1In		0x0		// RW
#define	ioSIN1In		0x0		// RW
#define	ioCOSM1In		0x0		// RW
#define	ioSINM1In		0x0		// RW
#define	ioSECTOR1In		0x0		// RW
#define	ioSECTORM1In	0x0		// RW
#define	ioIAO1In		0x0		// RW
#define	ioIBO1In		0x0		// RW
#define	ioICO1In		0x0		// RW
#define	ioIAADC1In		0x0		// RW
#define	ioIBADC1In		0x0		// RW
#define	ioICADC1In		0x0		// RW
#define	ioVDC1In		0x0		// RW
#define	ioID1In			0x0		// RW
#define	ioIQ1In			0x0		// RW

/***********************VE Common Register*****************************/
#define	ioMMODEIn		0x0		// 
#define	ioTADCIn		0x0		// 
#define	ioVCMPU0In		0x0		// RW R_Va_dt
#define	ioVCMPV0In		0x0		// RW R_Vb_dt
#define	ioVCMPW0In		0x0		// RW R_Vc_dt
#define	ioOUTCR0In		0x1FF	// 111111111B
#define	ioVTRGCMP00In	0x0		// 
#define	ioVTRGCMP10In	0x0		// 
#define	ioVTRGSEL0In	0x0		// 
#define	ioEMGRS0In		0x0		// 
#define	ioVCMPU1In		0x0		// 
#define	ioVCMPV1In		0x0		// 
#define	ioVCMPW1In		0x0		// 
#define	ioOUTCR1In		0x0		// 
#define	ioVTRGCMP01In	0x0		// 
#define	ioVTRGCMP11In	0x0		// 
#define	ioVTRGSEL1In	0x0		// 
#define	ioEMGRS1In		0x0		// 


/***  ADC *********************************************************************************************/

// ADCLK	Select ADC speed:
#define		cADCLK_2us					0x81	// ADxCLK set (convertion speed 2us)

// ADMOD0	ADC soft start set
#define		cADMOD0_Init				0x02	// ADC REF ON
#define		ADA_SOFT_START				ADA->MOD0 = 3			// ADC A soft start
#define		ADB_SOFT_START				ADB->MOD0 = 3			// ADC B soft start

// ADMOD1	ADC enable, monitor mode start
#define		ADA_ENABLE					ADA->MOD1 = 0x80		// ADC A Enable
#define		ADA_DISABLE					ADA->MOD1 = 0x00		// ADC A Disable
#define		ADB_ENABLE					ADB->MOD1 = 0x80		// ADC B Enable
#define		ADB_DISABLE					ADB->MOD1 = 0x00		// ADC B Disable

// ADMOD2	AD convertion check
#define		CHECK_AD0_BUSY				ADA->MOD2 & 0x01		// =1: ADC A bussy
#define		CHECK_AD0_S_BUSY			ADA->MOD2 & 0x02		// =1: ADC A soft-s bussy
#define		CHECK_AD1_BUSY				ADB->MOD2 & 0x01		// =1: ADC B bussy
#define		CHECK_AD1_S_BUSY			ADB->MOD2 & 0x02		// =1: ADC B soft-s bussy

// Define the constant data for ADCMPCR, ADCMP
// Set by the other file


/****************************************************************************************/
/*	Constant data set (not control parameter)											*/
/****************************************************************************************/

#define	PAI		3.14159265
#define	PAI2	2*PAI

#define	cClark0			21845L		/* 32768 * (1)       * 2/3 */
#define	cClark1			-10923L		/* 32768 * (-1/2)    * 2/3 */
#define	cClark2			-10923L		/* 32768 * (-1/2)    * 2/3 */
#define	cClark3			0L			/* 32768 * (0)       * 2/3 */
#define	cClark4			18919L		/* 32768 * (ROOT3/2) * 2/3 */
#define	cClark5			-18919L		/* 32768 * (-ROOT3/2)* 2/3 */
#define	cDIV_Q15_SQRT3	18919		/* 1 / ROOT3 * 32768 */
#define	cPWMPeriod		(UVAR16)(cIMCLK_FRQ* cPWMPRD / 2)		// Unit change from [us] to [1/fc]
#define	cDeadTime		(UVAR8)(cIMCLK_FRQ*1000000 * cDEADTIME/1000000 / 8)


/****************************************************************************************/
/*	Define The Macro																	*/
/****************************************************************************************/
// Type define
typedef signed char		VAR8;		/* signed 8-bit */
typedef signed short	VAR16;		/* signed 16-bit */
typedef signed long		VAR32;		/* signed 32-bit */
typedef unsigned char	UVAR8;		/* unsigned 8-bit */
typedef unsigned short	UVAR16;		/* unsigned 16-bit */
typedef unsigned long	UVAR32;		/* unsigned 32-bit */

#define	T_32Q31		S_WORD		/* 32bit Q31format */
#define	T_32Q16		S_WORD		/* 32bit Q16format */
#define	T_16Q16		UVAR16		/* 16bit Q16format */
#define	T_16Q15		VAR16		/* 16bit Q15format */

#define	SET			1				/* Bit set */
#define	CLEAR		0				/* Bit clear */
#define	HIGH		1
#define	LOW			0

#define	FIXPOINT_12		0x1000				/* fix point Q12 4096 */
#define	FIXPOINT_15		0x8000				/* fix point Q15 32768 */
#define	FIXPOINT_16		0x10000				/* fix point Q16 65536 */
#define	FIXPOINT_31		0x80000000			/* fix point Q31 */
#define	cROUND_BIT15	0x00008000			/* Rounding off */

#define	BIT8( a,b,c,d,e,f,g,h )	( (a)*0x80+(b)*0x40+(c)*0x20+(d)*0x10 + (e)*0x08+(f)*0x04+(g)*0x02+(h)*0x01 )
#define	BIT16( a,b,c,d,e,f,g,h,aa,bb,cc,dd,ee,ff,gg,hh )	( (a)*0x8000+(b)*0x4000+(c)*0x2000+(d)*0x1000 + (e)*0x0800+(f)*0x0400+(g)*0x0200+(h)*0x0100 + (aa)*0x0080+(bb)*0x0040+(cc)*0x0020+(dd)*0x0010 + (ee)*0x0008+(ff)*0x0004+(gg)*0x0002+(hh)*0x0001 )

#define	b_set(a,b)		((a) = (a) | (1 << (b)))	/* bit Set   */
#define	b_clr(a,b)		((a) = (a) & ~(1 << (b)))	/* Bit Clear */

// Declaration of structure
typedef struct{
	UVAR16	F_user_modul	:1;		/* PWM Moduration	0=2phase	1=3phase		*/
	UVAR16	reserve			:7;		/* reserve 										*/
	UVAR16	steady			:4;		/* Steady state		0=Steady A 					*/
	UVAR16	start			:2;		/* Start mode		unuse						*/
	UVAR16	F_user_encoder	:1;		/* Position by...	0=Currnet, 1=Encoder		*/
	UVAR16	F_user_onoff	:1;		/* Motor ON/OFF		0=off, 1=on					*/
}T_ComUser;

// Nibble based half field type definition
typedef struct {
	UVAR8 hhigh	:4;		/* bit12-15 */
	UVAR8 lhigh	:4;		/* bit8-11 */
	UVAR8 hlow	:4;		/* bit4-7 */
	UVAR8 llow	:4;		/* bit0-3 */
} HNIBLE_FIELD;

// Half field type definition
typedef struct {
	UVAR16 b15	:1;		/* bit15 */
	UVAR16 b14	:1;		/* bit14 */
	UVAR16 b13	:1;		/* bit13 */
	UVAR16 b12	:1;		/* bit12 */
	UVAR16 b11	:1;		/* bit11 */
	UVAR16 b10	:1;		/* bit10 */
	UVAR16 b9	:1;		/* bit9 */
	UVAR16 b8	:1;		/* bit8 */
	UVAR16 b7	:1;		/* bit7 */
	UVAR16 b6	:1;		/* bit6 */
	UVAR16 b5	:1;		/* bit5 */
	UVAR16 b4	:1;		/* bit4 */
	UVAR16 b3	:1;		/* bit3 */
	UVAR16 b2	:1;		/* bit2 */
	UVAR16 b1	:1;		/* bit1 */
	UVAR16 b0	:1;		/* bit0 */
} HALF_FIELD;

typedef union {
	UVAR16	half;
	UVAR8	byte[2];
	HNIBLE_FIELD	nibble;
	HALF_FIELD	bit;
} HALF;

enum _mainstage {
	cStop = 0,
	cInitposition,
	cForce,
	cChange_up,
	cSteady_A,
	cEmergency
};

enum _substage {
	cStep0 = 0,
	cStep1,
	cStep2,
	cStep3,
	cStep4,
	cStep5,
	cStep6,
	cStepEnd
};

typedef	struct{
	enum _mainstage		main;
	enum _substage		sub;
}Stage;

typedef union {
	signed long		word;
	signed short	half[2];
	signed char		byte[4];
} S_WORD;


/****************************************************************************************/
/*	Definition of variable																*/
/****************************************************************************************/

EXTERN	T_ComUser	S_com_user;		// Control command by User order
EXTERN	T_ComUser	S_com_user_1;	//    before step Scom_user

#define	cHIST_NUM	5
EXTERN	Stage				S_stage;
EXTERN	HALF				R_state;

EXTERN	struct{
	UVAR16	reserve			:7;		/* reserve */
	UVAR16	F_comm_modul	:1;		/* PWM Moduratio	0=2phase modulation		1=3phase modulation					*/
	UVAR16	F_comm_encoder	:1;		/* Psition detect	0=Current				1=Encoder							*/
	UVAR16	F_comm_theta	:1;		/* Omega to Theta	0=command value			1=Calculate the theta from omega.	*/
	UVAR16	F_comm_omega	:1;		/* Omega by			0=command value			1=Result of Estimation position		*/
	UVAR16	F_comm_current	:1;		/* Current by		0=command value			1=Result of Speed Control			*/
	UVAR16	F_comm_volt		:1;		/* Voltage by		0=command value			1=Result of Current Control			*/
	UVAR16	F_comm_Edetect	:1;		/* Position detect	0=off					1=on								*/
	UVAR16	F_comm_Idetect	:1;		/* Current detect	0=off					1=on								*/
	UVAR16	F_comm_onoff	:1;		/* PWM output		0=off					1=on								*/
}R_command;		// Command instruction


EXTERN	T_32Q31				S_sp_ud_lim_f_user;	/* Limitation of the increase value (Forced Stage) */
EXTERN	T_32Q31				S_sp_up_lim_s_user;	/* Limitation of the increase value (Steady Stage) */
EXTERN	T_32Q31				S_sp_dn_lim_s_user;	/* Limitation of the decrease value (Steady Stage) */
EXTERN	UVAR16				S_Initp_time_user;	/* Time of Positioning State */
EXTERN	UVAR16				S_go_up_time_user;	/* Time of Change-up state */
EXTERN	T_32Q31				R_omega_com;		/* [Hz/maxHz] Command of Omega(electrical angle)  */
EXTERN	T_32Q31				R_Id_com;			/* [A/maxA] Command of d-axis current */
EXTERN	T_32Q31				R_Iq_com;			/* [A/maxA] Command of q-axis current */
EXTERN	T_16Q15				R_Vd_com;			/* [V/maxV] Command of d-axis voltage */
EXTERN	T_16Q15				R_Vq_com;			/* [V/maxV] Command of q-axis voltage */
EXTERN	T_16Q15				R_theta_com;		/* [---] Command of theta of motor */
EXTERN	HALF				R_state;			/* Motor state */

EXTERN	T_16Q15				R_Ia;				/* [A/maxA] a phase current */
EXTERN	T_16Q15				R_Ib;				/* [A/maxA] b phase current */
EXTERN	T_16Q15				R_Ic;				/* [A/maxA] c phase current */

EXTERN	T_16Q15				R_Ia_TEST;			/* [A/maxA] a phase current */
EXTERN	T_16Q15				R_Ib_TEST;			/* [A/maxA] b phase current */
EXTERN	T_16Q15				R_Ic_TEST;			/* [A/maxA] c phase current */

EXTERN	T_16Q15				R_Id;				/* [A/maxA] d-axis current */
EXTERN	T_16Q15				R_Iq;				/* [A/maxA] q-axis current */

EXTERN	T_16Q15				R_Id_ref;			/* [A/maxA] Referense of d-axis current */
EXTERN	T_16Q15				R_Iq_ref;			/* [A/maxA] Referense of q-axis current */
EXTERN	T_32Q31				R_Iq_ref_I;			/* [A/maxA] Referense of q-axis current (Integral) */

EXTERN	T_16Q15				R_Id_dev;			/* [A/maxA] Deviation value of d-axis current */
EXTERN	T_16Q15				R_Iq_dev;			/* [A/maxA] Deviation value of q-axis current */

EXTERN	T_16Q15				R_Iao;				/* [---] a phase zero current */
EXTERN	T_16Q15				R_Ibo;				/* [---] b phase zero current */
EXTERN	T_16Q15				R_Ico;				/* [---] c phase zero current */

EXTERN	T_16Q15				R_Ialpha;			/* [A/maxA] Alpha phase current */
EXTERN	T_16Q15				R_Ibeta;			/* [A/maxA] Beta phase current */

EXTERN	T_16Q15				R_Ia_adc;			/* [---] a phase current ADC  */
EXTERN	T_16Q15				R_Ib_adc;			/* [---] b phase current ADC  */
EXTERN	T_16Q15				R_Ic_adc;			/* [---] c phase current ADC  */

EXTERN	T_32Q31				R_Vd;				/* [V/maxV] d-axis voltage */
EXTERN	T_32Q31				R_Vq;				/* [V/maxV] q-axis voltage */
EXTERN	T_32Q31				R_Vd_TEST;			/* [V/maxV] d-axis voltage (at No current control) */
EXTERN	T_32Q31				R_Vq_TEST;			/* [V/maxV] q-axis voltage (at No current control) */

EXTERN	T_32Q31				R_Vd_I;				/* [V/maxV] d-axis voltage (Integral) */
EXTERN	T_32Q31				R_Vq_I;				/* [V/maxV] q-axis voltage (Integral) */
EXTERN	T_32Q31				R_Vd_1;				/* [V/maxV] d-axis voltage (Saved) */
EXTERN	T_32Q31				R_Vq_1;				/* [V/maxV] q-axis voltage (Saved) */

EXTERN	T_16Q15				R_Ed;				/* [V/maxV] d-axis induced voltage  */
EXTERN	T_16Q15				R_Eq;				/* [V/maxV] q-axis induced voltage  */

EXTERN	T_16Q15				R_Vdc_adc;			/* [---] DC voltage from ADC */
EXTERN	T_16Q15				R_Vdc;				/* [V/maxV] DC voltage */
EXTERN	T_16Q15				R_Vdc1;				/* [V/maxV] DC voltage */

EXTERN	T_16Q15				R_Valpha;			/* [V/maxV] Alpha phase voltage */
EXTERN	T_16Q15				R_Vbeta;			/* [V/maxV] Beta phase voltage */

EXTERN	T_16Q15				R_Valpha_Temp;		/* [V/maxV] Alpha phase voltage (Temporary) */
EXTERN	T_16Q15				R_Vbeta_Temp;		/* [V/maxV] Beta phase voltage (Temporary) */

EXTERN	VAR16				R_Va_dt;			/* [---] a phase PWM duty */
EXTERN	VAR16				R_Vb_dt;			/* [---] b phase PWM duty */
EXTERN	VAR16				R_Vc_dt;			/* [---] c phase PWM duty */

EXTERN	T_32Q31				R_omega;			/* [Hz/maxHz] Omega(speed): Electrical angle  */
EXTERN	T_32Q31				R_omega_I;			/* [Hz/maxHz]             : Integration value */
EXTERN	T_16Q15				R_omega_dev;		/* [Hz/maxHz]             : Save              */

EXTERN	T_32Q31				R_theta;			/* [---] Electrical angle(position) -180 ~+180deg */
EXTERN	UVAR16				R_Sector;			/* Sector */
EXTERN	UVAR16				R_Icont_Counter; 	/* Intrruption counter */
EXTERN	VAR16				S_lambda_user;		/* [deg/360] Lambda by User command */
EXTERN	UVAR16				S_stage_counter;	/* Stage counter */

EXTERN	T_16Q15				S_Id_st_user;		/* [A/maxA] Start d-axis current by user */
EXTERN	T_16Q15				S_Iq_st_user;		/* [A/maxA] Start q-axis current by user */
EXTERN	T_16Q15				S_Id_com_user;		/* [A/maxA] d-axis current by user */
EXTERN	T_16Q15				S_Iq_com_user;		/* [A/maxA] q-axis current by user */
EXTERN	T_32Q31				S_omega_user;		/* [Hz/maxHz] Target omega by user */

EXTERN	T_32Q16				R_D0;				/* Duty on the Space Vector for t3 */
EXTERN	T_32Q16				R_D1;				/* Duty on the Space Vector for t1 */
EXTERN	T_32Q16				R_D2;				/* Duty on the Space Vector for t2 */

/*===================================================================*
      Proto Type Definition
 *===================================================================*/
EXTERN	short	E_Sine(short theta);
EXTERN	short	E_Cosine(short theta);
EXTERN	VAR32 sadd32(VAR32 a, VAR32 b);
EXTERN	int ssub32(int a, int b);

// Encoder setting
EXTERN	VAR16	R_omega_enc;
EXTERN	VAR16	R_theta_enc;
EXTERN	VAR16	R_EnCnt,R_EnCnt1;
EXTERN	VAR16	R_EnCnt_dev,R_EncCntdevAve;

EXTERN	UVAR16 temp1;
EXTERN	UVAR16 temp2;
EXTERN	UVAR16 temp3;
EXTERN	UVAR16 temp4;
EXTERN	UVAR16 temp5;
EXTERN	UVAR16 temp6;
EXTERN	UVAR16 temp7;
EXTERN	UVAR16 temp8;
EXTERN	UVAR16 temp9;
EXTERN	UVAR16 temp10;
EXTERN	UVAR16 temp11;
EXTERN	UVAR16 temp12;
EXTERN	UVAR16 temp13;
EXTERN	UVAR16 temp14;
EXTERN	UVAR16 temp15;
EXTERN	UVAR16 temp17;
EXTERN	UVAR16 temp18;
EXTERN	UVAR16 temp19;
EXTERN	UVAR16 temp20;
EXTERN	UVAR16 temp21;
EXTERN	UVAR16 temp22;
EXTERN	UVAR16 temp23;
EXTERN	UVAR16 temp24;
EXTERN	UVAR16 temp25;

#undef EXTERN
#endif

