/*******************************************************************************
* File Name 		 : m370_int.h
* Version			 : V1.0
* Date				 : 2009/06/23
* Description		 : SFR define
********************************************************************************/

#ifndef __M370_INT_H
#define __M370_INT_H


/***************************************************************************
 **
 **  TMPM370FxFG Interrupt Lines
 **
 ***************************************************************************/
#define MAIN_STACK             0          /* Main Stack                   */
#define RESETI                 1          /* Reset                        */
#define NMII                   2          /* Non-maskable Interrupt       */
#define HFI                    3          /* Hard Fault                   */
#define MMI                    4          /* Memory Management            */
#define BFI                    5          /* Bus Fault                    */
#define UFI                    6          /* Usage Fault                  */
#define SVCI                  11          /* SVCall                       */
#define DMI                   12          /* Debug Monitor                */
#define PSI                   14          /* PendSV                       */
#define STI                   15          /* SysTick                      */
#define EII                   16          /* External Interrupt           */
#define INT0                 ( 0 + EII)   /* Interrupt pin (PH0/96pin)    */
#define INT1                 ( 1 + EII)   /* Interrupt pin (PH1/95pin)    */
#define INT2                 ( 2 + EII)   /* Interrupt pin (PH2/94pin)    */
#define INT3                 ( 3 + EII)   /* Interrupt pin (PA0/2pin)    */
#define INT4                 ( 4 + EII)   /* Interrupt pin (PA2/4pin)     */
#define INT5                 ( 5 + EII)   /* Interrupt pin (PE4/15pin)    */
#define INTRX0               ( 6 + EII)   /* Serial reception (channel.0) */
#define INTTX0               ( 7 + EII)   /* Serial transmit (channel.0)  */
#define INTRX1               ( 8 + EII)   /* Serial reception (channel.1) */
#define INTTX1               ( 9 + EII)   /* Serial transmit (channel.1)  */
#define INTVCNA              (10 + EII)   /* Vector Engine A              */
#define INTVCNB              (11 + EII)   /* Vector Engine B              */
#define INTEMG0              (12 + EII)   /* PMD0 EMG (Emagency stop)     */
#define INTEMG1              (13 + EII)   /* PMD1 EMG (Emagency stop)     */
#define INTOVV0              (14 + EII)   /* PMD0 OVV (Over Voltage)      */
#define INTOVV1              (15 + EII)   /* PMD1 OVV (Over Voltage)      */
#define INTAD0PDA            (16 + EII)   /* ADC0 Finish of PMD0 trigger start convertion */
#define INTAD1PDA            (17 + EII)   /* ADC1 Finish of PMD0 trigger start convertion */
#define INTAD0PDB            (18 + EII)   /* ADC0 Finish of PMD1 trigger start convertion */
#define INTAD1PDB            (19 + EII)   /* ADC1 Finish of PMD1 trigger start convertion */
#define INTTB00              (20 + EII)   /* 16bit TMRB0 match detection 0 */
#define INTTB01              (21 + EII)   /* 16bit TMRB0 match detection 1 */
#define INTTB10              (22 + EII)   /* 16bit TMRB1 match detection 0 */
#define INTTB11              (23 + EII)   /* 16bit TMRB1 match detection 1 */
#define INTTB40              (24 + EII)   /* 16bit TMRB4 match detection 0 */
#define INTTB41              (25 + EII)   /* 16bit TMRB4 match detection 1 */
#define INTTB50              (26 + EII)   /* 16bit TMRB5 match detection 0 */
#define INTTB51              (27 + EII)   /* 16bit TMRB5 match detection 1 */
#define INTPMD0              (28 + EII)   /* PMD0 PWM Interrupt            */
#define INTPMD1              (29 + EII)   /* PMD1 PWM Interrupt            */
#define INTCAP00             (30 + EII)   /* 16bit TMRB0 input capture 0   */
#define INTCAP01             (31 + EII)   /* 16bit TMRB0 input capture 1   */
#define INTCAP10             (32 + EII)   /* 16bit TMRB1 input capture 0   */
#define INTCAP11             (33 + EII)   /* 16bit TMRB1 input capture 1   */
#define INTCAP40             (34 + EII)   /* 16bit TMRB2 input capture 0   */
#define INTCAP41             (35 + EII)   /* 16bit TMRB2 input capture 1   */
#define INTCAP50             (36 + EII)   /* 16bit TMRB3 input capture 0   */
#define INTCAP51             (37 + EII)   /* 16bit TMRB3 input capture 1   */
#define INT6                 (38 + EII)   /* Interrupt pin (PE6/17pin)     */
#define INT7                 (39 + EII)   /* Interrupt pin (PE7/18pin)     */
#define INTRX2               (40 + EII)   /* Serial reception (channel.2)  */
#define INTTX2               (41 + EII)   /* Serial transmission (channel.2)*/
#define INTAD0CPA            (42 + EII)   /* ADC0 Monitor A                */
#define INTAD1CPA            (43 + EII)   /* ADC1 Monitor A                */
#define INTAD0CPB            (44 + EII)   /* ADC0 Monitor B                */
#define INTAD1CPB            (45 + EII)   /* ADC1 Monitor B                */
#define INTTB20              (46 + EII)   /* 16bit TMRB2 match detection 0 */
#define INTTB21              (47 + EII)   /* 16bit TMRB2 match detection 1 */
#define INTTB30              (48 + EII)   /* 16bit TMRB3 match detection 0 */
#define INTTB31              (49 + EII)   /* 16bit TMRB3 match detection 1 */
#define INTCAP20             (50 + EII)   /* 16bit TMRB2 input capture 0   */
#define INTCAP21             (51 + EII)   /* 16bit TMRB2 input capture 1   */
#define INTCAP30             (52 + EII)   /* 16bit TMRB3 input capture 0   */
#define INTCAP31             (53 + EII)   /* 16bit TMRB3 input capture 1   */
#define INTAD0SFT            (54 + EII)   /* ADC0 Finish of PMD0 soft start convertion */
#define INTAD1SFT            (55 + EII)   /* ADC1 Finish of PMD0 soft start convertion */
#define INTAD0TMR            (56 + EII)   /* ADC0 Finish of PMD1 timer start convertion */
#define INTAD1TMR            (57 + EII)   /* ADC1 Finish of PMD1 timer start convertion */
#define INT8                 (58 + EII)   /* Interrupt pin (PA7/9pin)      */
#define INT9                 (59 + EII)   /* Interrupt pin (PD3/33pin)     */
#define INTA                 (60 + EII)   /* Interrupt pin (FTEST2/21pin)  */
#define INTB                 (61 + EII)   /* Interrupt pin (FTEST3/20pin)  */
#define INTENC0              (62 + EII)   /* Encoder timer 0               */
#define INTENC1              (63 + EII)   /* Encoder timer 1               */
#define INTRX3               (64 + EII)   /* Serial reception (channel.3)  */
#define INTTX3               (65 + EII)   /* Serial transmission (channel.3)*/
#define INTTB60              (66 + EII)   /* 16bit TMRB6 match detection 0 */
#define INTTB61              (67 + EII)   /* 16bit TMRB6 match detection 1 */
#define INTTB70              (68 + EII)   /* 16bit TMRB7 match detection 0 */
#define INTTB71              (69 + EII)   /* 16bit TMRB7 match detection 1 */
#define INTCAP60             (70 + EII)   /* 16bit TMRB6 input capture 0   */
#define INTCAP61             (71 + EII)   /* 16bit TMRB6 input capture 1   */
#define INTCAP70             (72 + EII)   /* 16bit TMRB7 input capture 0   */
#define INTCAP71             (73 + EII)   /* 16bit TMRB7 input capture 1   */
#define INTC                 (74 + EII)   /* Interrupt pin (PJ6/74pin)     */
#define INTD                 (75 + EII)   /* Interrupt pin (PJ7/73pin)     */
#define INTE                 (76 + EII)   /* Interrupt pin (PK0/72pin)     */
#define INTF                 (77 + EII)   /* Interrupt pin (PK1/71pin)     */


#define EXT_INT0                0   /* Interrupt pin (PH0/96pin)    */
#define EXT_INT1                1   /* Interrupt pin (PH1/95pin)    */
#define EXT_INT2                2   /* Interrupt pin (PH2/94pin)    */
#define EXT_INT3                3   /* Interrupt pin (PA0/2pin)    */
#define EXT_INT4                4   /* Interrupt pin (PA2/4pin)     */
#define EXT_INT5                5   /* Interrupt pin (PE4/15pin)    */
#define EXT_INTRX0              6   /* Serial reception (channel.0) */
#define EXT_INTTX0              7   /* Serial transmit (channel.0)  */
#define EXT_INTRX1              8   /* Serial reception (channel.1) */
#define EXT_INTTX1              9   /* Serial transmit (channel.1)  */
#define EXT_INTVCNA            10   /* Vector Engine A              */
#define EXT_INTVCNB            11   /* Vector Engine B              */
#define EXT_INTEMG0            12   /* PMD0 EMG (Emagency stop)     */
#define EXT_INTEMG1            13   /* PMD1 EMG (Emagency stop)     */
#define EXT_INTOVV0            14   /* PMD0 OVV (Over Voltage)      */
#define EXT_INTOVV1            15   /* PMD1 OVV (Over Voltage)      */
#define EXT_INTAD0PDA          16   /* ADC0 Finish of PMD0 trigger start convertion */
#define EXT_INTAD1PDA          17   /* ADC1 Finish of PMD0 trigger start convertion */
#define EXT_INTAD0PDB          18   /* ADC0 Finish of PMD1 trigger start convertion */
#define EXT_INTAD1PDB          19   /* ADC1 Finish of PMD1 trigger start convertion */
#define EXT_INTTB00            20   /* 16bit TMRB0 match detection 0 */
#define EXT_INTTB01            21   /* 16bit TMRB0 match detection 1 */
#define EXT_INTTB10            22   /* 16bit TMRB1 match detection 0 */
#define EXT_INTTB11            23   /* 16bit TMRB1 match detection 1 */
#define EXT_INTTB40            24   /* 16bit TMRB4 match detection 0 */
#define EXT_INTTB41            25   /* 16bit TMRB4 match detection 1 */
#define EXT_INTTB50            26   /* 16bit TMRB5 match detection 0 */
#define EXT_INTTB51            27   /* 16bit TMRB5 match detection 1 */
#define EXT_INTPMD0            28   /* PMD0 PWM Interrupt            */
#define EXT_INTPMD1            29   /* PMD1 PWM Interrupt            */
#define EXT_INTCAP00           30   /* 16bit TMRB0 input capture 0   */
#define EXT_INTCAP01           31   /* 16bit TMRB0 input capture 1   */
#define EXT_INTCAP10           32   /* 16bit TMRB1 input capture 0   */
#define EXT_INTCAP11           33   /* 16bit TMRB1 input capture 1   */
#define EXT_INTCAP40           34   /* 16bit TMRB2 input capture 0   */
#define EXT_INTCAP41           35   /* 16bit TMRB2 input capture 1   */
#define EXT_INTCAP50           36   /* 16bit TMRB3 input capture 0   */
#define EXT_INTCAP51           37   /* 16bit TMRB3 input capture 1   */
#define EXT_INT6               38   /* Interrupt pin (PE6/17pin)     */
#define EXT_INT7               39   /* Interrupt pin (PE7/18pin)     */
#define EXT_INTRX2             40   /* Serial reception (channel.2)  */
#define EXT_INTTX2             41   /* Serial transmission (channel.2)*/
#define EXT_INTAD0CPA          42   /* ADC0 Monitor A                */
#define EXT_INTAD1CPA          43   /* ADC1 Monitor A                */
#define EXT_INTAD0CPB          44   /* ADC0 Monitor B                */
#define EXT_INTAD1CPB          45   /* ADC1 Monitor B                */
#define EXT_INTTB20            46   /* 16bit TMRB2 match detection 0 */
#define EXT_INTTB21            47   /* 16bit TMRB2 match detection 1 */
#define EXT_INTTB30            48   /* 16bit TMRB3 match detection 0 */
#define EXT_INTTB31            49   /* 16bit TMRB3 match detection 1 */
#define EXT_INTCAP20           50   /* 16bit TMRB2 input capture 0   */
#define EXT_INTCAP21           51   /* 16bit TMRB2 input capture 1   */
#define EXT_INTCAP30           52   /* 16bit TMRB3 input capture 0   */
#define EXT_INTCAP31           53   /* 16bit TMRB3 input capture 1   */
#define EXT_INTAD0SFT          54   /* ADC0 Finish of PMD0 soft start convertion */
#define EXT_INTAD1SFT          55   /* ADC1 Finish of PMD0 soft start convertion */
#define EXT_INTAD0TMR          56   /* ADC0 Finish of PMD1 timer start convertion */
#define EXT_INTAD1TMR          57   /* ADC1 Finish of PMD1 timer start convertion */
#define EXT_INT8               58   /* Interrupt pin (PA7/9pin)      */
#define EXT_INT9               59   /* Interrupt pin (PD3/33pin)     */
#define EXT_INTA               60   /* Interrupt pin (FTEST2/21pin)  */
#define EXT_INTB               61   /* Interrupt pin (FTEST3/20pin)  */
#define EXT_INTENC0            62   /* Encoder timer 0               */
#define EXT_INTENC1            63   /* Encoder timer 1               */
#define EXT_INTRX3             64   /* Serial reception (channel.3)  */
#define EXT_INTTX3             65   /* Serial transmission (channel.3)*/
#define EXT_INTTB60            66   /* 16bit TMRB6 match detection 0 */
#define EXT_INTTB61            67   /* 16bit TMRB6 match detection 1 */
#define EXT_INTTB70            68   /* 16bit TMRB7 match detection 0 */
#define EXT_INTTB71            69   /* 16bit TMRB7 match detection 1 */
#define EXT_INTCAP60           70   /* 16bit TMRB6 input capture 0   */
#define EXT_INTCAP61           71   /* 16bit TMRB6 input capture 1   */
#define EXT_INTCAP70           72   /* 16bit TMRB7 input capture 0   */
#define EXT_INTCAP71           73   /* 16bit TMRB7 input capture 1   */
#define EXT_INTC               74   /* Interrupt pin (PJ6/74pin)     */
#define EXT_INTD               75   /* Interrupt pin (PJ7/73pin)     */
#define EXT_INTE               76   /* Interrupt pin (PK0/72pin)     */
#define EXT_INTF               77   /* Interrupt pin (PK1/71pin)     */



	/* ICRCG */			/* API_INT_ReqClr */
#define IP_INT_CLR_INT0			0x00		/* INT0 ReqClr			 */
#define IP_INT_CLR_INT1			0x01		/* INT1 ReqClr			 */
#define IP_INT_CLR_INT2			0x02		/* INT2 ReqClr			 */
#define IP_INT_CLR_INT3			0x03		/* INT3 ReqClr			 */
#define IP_INT_CLR_INT4			0x04		/* INT4 ReqClr			 */
#define IP_INT_CLR_INT5			0x05		/* INT5 ReqClr			 */
#define IP_INT_CLR_INTCECRX		0x06		/* INTCEC ReqClr		 */
#define IP_INT_CLR_INTRMCRX0	0x07		/* INTRMCRX0 ReqClr		 */
#define IP_INT_CLR_INTRTC		0x08		/* INTRTC ReqClr		 */
#define IP_INT_CLR_INT6			0x09		/* INT6 ReqClr			 */
#define IP_INT_CLR_INT7			0x0A		/* INT7 ReqClr			 */
#define IP_INT_CLR_INTRMCRX1	0x0B		/* INTRMCRX1 ReqClr		 */
#define	IP_INT_CLR_INTCECTX		0x0c

	/* IMCGA,IMCGB,IMCGC,IMCGD */			/* API_INT_ActSt_Set */
#define IP_INT_ACTST_L			0x00		/* Standby Active State "L"	 */
#define IP_INT_ACTST_H			0x10		/* Standby Active State "H"	 */
#define IP_INT_ACTST_FALLING	0x20		/* Standby Active State "FALLING"	 */
#define IP_INT_ACTST_RISING		0x30		/* Standby Active State "RISING"	 */
#define IP_INT_ACTST_BOTH		0x40		/* Standby Active State "BOTH(FALLING,RISING)"	 */

	/* IMCGA,IMCGB,IMCGC,IMCGD */			/* API_INT_Enable */
#define IP_INT_DIS			0x00		/* Interrupt Disable	 */
#define IP_INT_ENA			0x01		/* Interrupt Enable	 */



void API_INT_Init(void);
void API_INT_claer_Init(void);
void API_CG_Active_Set(uint8_t ip_intnum, uint8_t active, uint8_t enable);
void API_CG_Active_Reset(void);
void API_INT_CER_All_Set(void);
void API_INT_CER_Set(uint8_t intnum);
void API_INT_PR_Set(uint8_t intnum, uint8_t pri);
void API_INT_PR_Reset(void);
void API_INT_SPR_ALL_Set(void);
void API_INT_SPR_Set(uint8_t intnum);
void API_INT_SER_Set(uint8_t intnum);


#endif

/*************************** END OF FILE **************************************/

