#include <stdlib.h>
#include	"TMPM370.h"

#define	DEFINE_APP
#include	"ipdefine.h"
#undef	DEFINE_APP
#include	"D_Para.h"
#include	"main.h"
#include	"initial.h"


/*==================================================================*
      Main Routine (Start of Program)
*===================================================================*/
void	main()
{

/*==== Initial Setting     ========================================*/

	__disable_irq();		// DI
	init_WDTdis();			/* WDT Disable */
	
	GEAR_TOP();				/* System clock 80MHz set */
	init_PORT();			/* Setting of all PORT */
	init_ENC0en();			/* Setting of INTENC */
	init_DAC();				/* Setting of UART for DAC */
	init_ADCen();			/* Setting of ADC0,1 & Wait TRG */

	VE_Initialize();		/* Setting of VE & start */
	STOP_0DETECT=0;
	VE->MODE0 = 0x0; 			
	VE->TASKAPP = 0x0; 		
	VE->ACTSCH = 0x9; 		
	VE->CPURUNTRG = 0x1;

//	__DSB();    			// SYNC
	__enable_irq();			// EI

	main_loop();			// Main Loop
}

/*==================================================================*
      Main Loop
*===================================================================*/
void	main_loop()
{
	init_WDTclr();			// WDT clear

	while(1) {
		if(M_Main_Counter >= cMainLoopTime) {
			M_Main_Counter = 0;
		   	 init_WDTclr();			/// WDT CODE CLEAR

			/***** User control   *****/
			B_User_Control();

			/***** Motor control  *****/
			C_Control_Ref_Model();	// Change of stage
			C_Common();				// Stage Functions
			C_Stage_Stop();			// Stop
			C_Stage_Emergency();	// Emargensy
			C_Stage_Initposition();	// Positioning
			C_Stage_Force();		// Force commutation
			C_Stage_Change_up();	// Change up 
			C_Stage_Steady_A();		// Normal RUN A (Speed control by currnt)
		}
	}
} 


/*===================================================================*
      SUB ROUTINES
 *===================================================================*/

/*===================================================================*
      User Control
 *===================================================================*/
void	B_User_Control(void)
{

	C_SG_SW_Input();		// SG Key input
	C_TOG_SW_Input();		// Toggle SW input
	C_LED_Output();			// 7seg LED output
	B_User_Ram_Output();	// Display data set


	SG_SW_data[0] = (PH->DATA >>4) & 0x0F;		// SW data(PH4-7)

	if((SG_SW_data[0] & 0x01) ==0){			// SW4 =L
		S_com_user.F_user_onoff = 0;		// Motor OFF
		S_com_user.F_user_encoder = 0;
		S_com_user.start = 0;
	}else{									// SW4 =H
		S_com_user.F_user_onoff = 1;		// Motor ON
		S_com_user.start = 0;
		
		if((SG_SW_data[0] & 0x02) ==0){			// SW3 =L
			S_com_user.F_user_encoder = 1;		// Position by Encoder
		}else{									// SW3 =H
			S_com_user.F_user_encoder = 0;		// Position by Current
		}
	}

	if(CHECK_EMG0_STATE){			// EMG state
		F_state_emg_H = SET;		// set F_state Flag
	}else{
		F_state_emg_H = CLEAR;		// clear F_state Flag
	}

	S_lambda_user = 0;				// Lambda command

	if(SG_SW_data[0] & 0x04){		// SW2:set motor speed on D_para.h
		S_omega_user.half[1] = (VAR16)(S_speed_act0*FIXPOINT_15 / cHz_MAX );
	}else{
		S_omega_user.half[1] = (VAR16)(S_speed_act1*FIXPOINT_15 / cHz_MAX );
	}

	S_Id_st_user=(UVAR16)(S_Id_st_user_act * FIXPOINT_15 / cA_MAX);
									// Start Current (Id) command
	S_Iq_st_user=(UVAR16)(S_Iq_st_user_act * FIXPOINT_15 / cA_MAX);
									// Start Current (Iq) command
}
/*==================================================================*
	SG Swich Input
 *==================================================================*/
void	C_SG_SW_Input(void){}

/*==================================================================*
	Toggle SW Input
 *==================================================================*/
void	C_TOG_SW_Input(void){}

/*==================================================================*
	7seg LED data output
 *==================================================================*/
void	C_LED_Output(void){}

/*==================================================================*
	Ram data Output
 *==================================================================*/
void	B_User_Ram_Output(void){}

/*==================================================================*
	Change of Stage
 *==================================================================*/
void	C_Control_Ref_Model(void)
{
	if(S_com_user.F_user_onoff == CLEAR){
		S_stage.main = cStop;			// Set STOP Stage
		S_stage.sub = cStep0;
	}else if((F_state_emg_H == SET)||(F_state_emg_I == SET)||(F_state_emg_DC==SET)){
    	S_stage.main = cEmergency;		// Set Emergency Stage
		S_stage.sub = cStep0;
	}else if((S_com_user_1.F_user_onoff == CLEAR)&&(S_com_user.F_user_onoff == SET)){
		S_stage.main = cInitposition;	// Set positioning Stage
		S_stage.sub = cStep0;
	}else if((S_stage.main == cInitposition)&&(S_stage.sub == cStepEnd)){
		S_stage.main = cForce;			// Set Force Stage
		S_stage.sub = cStep0;
	}else if((S_stage.main == cForce)&&(S_stage.sub == cStepEnd)){
	  if(S_com_user.F_user_encoder == 1){	// Position by Encoder
		S_stage.main = cSteady_A;		// Set Steady Stage
		S_stage.sub = cStep0;
	  }else{
		S_stage.main = cChange_up;		// Set change-up Stage
		S_stage.sub = cStep0;
	  }
	}else if((S_stage.main == cChange_up)&&(S_stage.sub == cStepEnd)){
		S_stage.main = cSteady_A;		// Set Steady Stage
		S_stage.sub = cStep0;
	}

	S_com_user_1 = S_com_user;			// Save user command
}

/*==================================================================*
	Common setting
 *==================================================================*/
void	C_Common(void) //
{
	// Option setting
	R_command.F_comm_encoder = S_com_user.F_user_encoder;

	// Acceleration setting
	S_sp_ud_lim_f_user.word = (VAR32)(FIXPOINT_31*cMainLoopPrd*cFcdUDLim/cHz_MAX); // Speed up/down limit at Force
	S_sp_up_lim_s_user.word = (VAR32)(FIXPOINT_31*cMainLoopPrd*cStdUpLim/cHz_MAX); // Speed up limit at Steady
	S_sp_dn_lim_s_user.word = (VAR32)(FIXPOINT_31*cMainLoopPrd*cStdDwLim/cHz_MAX); // Speed down limit at Steady

	// Time setting
	S_Initp_time_user = (UVAR16)(cInitLen/cMainLoopPrd);		// Time of Positioning (Force)
	S_go_up_time_user = (UVAR16)(cGoUpDelayLen/cMainLoopPrd);	// Time of Change-up
}

/*==================================================================*
	Stop Stage function
 *==================================================================*/
void	C_Stage_Stop(void)
{
	if(S_stage.main == cStop){
		switch(S_stage.sub){
		case cStep0:
			S_stage.sub = cStep1;
			__disable_irq();
			R_command.F_comm_theta = CLEAR;
			R_command.F_comm_omega = CLEAR;
			R_command.F_comm_current = CLEAR;
			R_command.F_comm_Edetect = CLEAR;
			R_command.F_comm_onoff = CLEAR;

			ITR_STAGE=0;
			R_theta_com = 0;
			R_theta.word=0;
			sel_timer = 0;

			__enable_irq();

			R_omega_com.word = 0;
			R_Id_com.word = 0;
			R_Iq_com.word = 0;
			R_Vd_com = 0;
			R_Vq_com = 0;
			break;
		default:
			break;
		}
	}
}

/*==================================================================*
	Emergency Stage function
 *==================================================================*/
void	C_Stage_Emergency(void)
{
	if(S_stage.main == cEmergency){
		switch(S_stage.sub){
		case cStep0:
			MOTOR_OUTPUT_OFF;
			break;
		default:
			break;
		}
	}
}

/*==================================================================*
	Positioning Stage function
 *==================================================================*/
void	C_Stage_Initposition(void)
{
	if(S_stage.main == cInitposition){
		switch(S_stage.sub){
		case cStep0:
			__disable_irq();
			R_command.F_comm_theta = CLEAR;
			R_command.F_comm_omega = CLEAR;
			R_command.F_comm_current = CLEAR;
			R_command.F_comm_Edetect = CLEAR;
			R_command.F_comm_onoff = SET;
			S_stage_counter=0;
			ITR_STAGE=1;
			__enable_irq();
			R_omega_com.word = 0;
			R_Iq_com.word = 0;
			R_Id_com.word = 0;
			R_theta_com = S_lambda_user;
			S_stage.sub = cStep1;
			
		case cStep1:
			S_stage_counter++;
			if(S_stage_counter >= S_Initp_time_user){
				S_stage.sub = cStepEnd;
			}

			R_Id_com.word += (abs(S_Id_st_user)<<16) / S_Initp_time_user;

            if(R_Id_com.word>abs(S_Id_st_user)<<16){
			    R_Id_com.word= abs(S_Id_st_user)<<16;
			}  

			R_theta_com = S_lambda_user;
			break;

		case cStepEnd:
			R_Id_com.word = abs(S_Id_st_user)<<16;
			R_theta_com = S_lambda_user;
			break;

		default:
			break;
		}
    }
}

/*==================================================================*
	Force Stage function
 *==================================================================*/
void	C_Stage_Force(void)
{
	if(S_stage.main == cForce){
		switch(S_stage.sub){
		case cStep0:
			__disable_irq();
			R_command.F_comm_theta = SET;
			R_command.F_comm_omega = CLEAR;
			R_command.F_comm_current = CLEAR;
			R_command.F_comm_Edetect = SET;
			R_command.F_comm_onoff = SET;
			ITR_STAGE=2;
			R_Iq_com.word = 0;
			R_Id_com.word = abs(S_Id_st_user)<<16;

			__enable_irq();
			S_stage.sub = cStep1;
			//  No break. Continue to the next statements. 

		case cStep1:
			// If reach minimum frequency, it change to cStepEnd 
			if(abs(R_omega_com.half[1]) >= (VAR16)(FIXPOINT_15 * cHz_MIN /cHz_MAX)){
				S_stage.sub = cStepEnd;
			}
			// No break. Continue to the next statements. 

		case cStepEnd:
			// Update drive frequency. 
			R_omega_com.word = C_command_limit_sub(R_omega_com.word, S_omega_user.word, S_sp_ud_lim_f_user.word, S_sp_ud_lim_f_user.word);
			break;

		default:
			break;
		}
	}
}

/*==================================================================*
	Change-Up Stage function
 *==================================================================*/
static T_32Q31 S_lambda_cal;
void	C_Stage_Change_up(void)
{
	T_32Q31 id_temp,iq_temp;
	if(S_stage.main == cChange_up){
		switch(S_stage.sub){
		case cStep0:
			S_stage.sub = cStep1;
			S_lambda_cal.word = 0;

			__disable_irq();
			R_command.F_comm_theta = SET;
			R_command.F_comm_omega = SET;
			R_command.F_comm_current = CLEAR;
			R_command.F_comm_Edetect = SET;
			R_command.F_comm_onoff = SET;
			ITR_STAGE=3;
			__enable_irq();
			// No break. Continue to the next statements. 

		case cStep1:
			S_lambda_cal.word += (abs(R_omega_com.half[1]) * (VAR32)(FIXPOINT_16*cHz_MAX*cMainLoopPrd))<< 1;
			if( S_lambda_cal.word > (ELE_DEG(90)<<16) ){
				S_lambda_cal.word = ELE_DEG(90)<<16;
			}
			id_temp.word = (S_Id_st_user * E_Cosine(S_lambda_cal.half[1])) << 1;
			iq_temp.word = (S_Iq_st_user * E_Sine(S_lambda_cal.half[1])) << 1;

			id_temp.word = abs(id_temp.word);
			iq_temp.word = abs(iq_temp.word);
			if(S_omega_user.half[1] < 0){
				iq_temp.word *= (-1);
			}

			__disable_irq();
			R_Id_com.word = id_temp.word;
			R_Iq_com.word = iq_temp.word;
			__enable_irq();

			// Update drive frequency. 
			R_omega_com.word = C_command_limit_sub(R_omega_com.word, S_omega_user.word, S_sp_ud_lim_f_user.word, S_sp_ud_lim_f_user.word);

			if( S_lambda_cal.word >= (ELE_DEG(90)<<16) ){
				S_stage_counter = 0;
				S_stage.sub = cStep3;
			}
			break;

		case cStep2:
			break;

		case cStep3:
			R_Id_com.word = 0;
			R_Iq_com.half[1] = S_Iq_st_user;		// add
			// Update drive frequency. 
			R_omega_com.word = C_command_limit_sub(R_omega_com.word,S_omega_user.word,S_sp_ud_lim_f_user.word,S_sp_ud_lim_f_user.word);
			S_stage_counter++;
			// End of change time? 
			if(S_stage_counter >= S_go_up_time_user){ // Set the Force Stage time
				S_stage.sub = cStepEnd;
			}
			break;

		default:
			break;
		}
	}
}


/*==================================================================*
	Steady Stage function
 *==================================================================*/
void	C_Stage_Steady_A(void)
{
	if(S_stage.main == cSteady_A){
		switch(S_stage.sub){
		case cStep0:
			__disable_irq();
			R_command.F_comm_theta = SET;
			R_command.F_comm_omega = SET;
			R_command.F_comm_current = SET;
			R_command.F_comm_Edetect = SET;
			R_command.F_comm_onoff = SET;
			ITR_STAGE=4;
			__enable_irq();
			S_stage.sub = cStep1;

			// No break. Continue to the next statements. 

		case cStep1:
			// Update drive frequency. 
			R_omega_com.word = C_command_limit_sub(R_omega_com.word, S_omega_user.word, S_sp_up_lim_s_user.word, S_sp_dn_lim_s_user.word);
			// Field-weaking control 
			R_Id_com.word = 0;
			break;

		default:
			break;
		}
	}
}

/*==================================================================*
	Check a Limitation of command     modified 2010.10.26
 *==================================================================*/
static VAR32 C_command_limit_sub(VAR32 now, VAR32 target, VAR32 lim_up, VAR32 lim_down)
{
	if (now == target) {
		return (target);
	}

	if (now >= 0) {
		// now speed is positive
		if (now < target) {						// UP
			if (target > now + lim_up) {
				return (now + lim_up);			//(__SADD(now,lim_up));
			}
			else {
				return (target);
			}
		}
		else {									// DOWN
			if (target < now - lim_up) {
				return (now - lim_up);			//(__SSUB(now,lim_down));
			}
			else {
				return (target);
			}
		}
	}
	else {
		// now speed is negative
		if (now > target) {						// UP
			if (target < now - lim_up) {
				//return (target < now - lim_up);	//(__SSUB(now,lim_up));
				return (now - lim_up);	//(__SSUB(now,lim_up));		//20101006 fixed  syoji
			}
			else {
				return (target);
			}
		}
		else {									// DOWN
			if (target > now + lim_up) {
				return (now + lim_up);			//(__SADD(now,lim_down));
			}
			else {
				return (target);
			}
		}
	}
}


/****************************************************************************************
 * Module   : E_Sine
 *---------------------------------------------------------------------------------------
 * Function : 
 * Input    : theta
 * Output   : 
 * Note     : sin(x) = 3.140625x + 0.02026367x^2 -5.325196x^3 + 0.5446778x^4 + 1.800293x^5
 ****************************************************************************************/
#define	cSine1	(VAR16)(FIXPOINT_12*3.140625)
#define	cSine2	(VAR16)(FIXPOINT_12*0.02026367)
#define	cSine3	(VAR16)(FIXPOINT_12*-5.325196)
#define	cSine4	(VAR16)(FIXPOINT_12*0.5446778)
#define	cSine5	(VAR16)(FIXPOINT_12*1.800293)

short	E_Sine(VAR16 theta)
{
	VAR16 x;
	VAR16 x1;
	VAR32 temp32;

	x = (VAR16)(theta & 0x7fff);
	if (x >= ELE_DEG(90)) {
		x = (VAR16)(ELE_DEG(180) - x);
	}
	x1 = x;
	temp32 = (cSine1*(VAR32)x1)<<1;
	x1 = (VAR16)(x1 * (VAR32)x>>(16-1));
	temp32 += (cSine2*(VAR32)x1)<<1;
	x1 = (VAR16)(x1 * (VAR32)x>>(16-1));
	temp32 += (cSine3*(VAR32)x1)<<1;
	x1 = (VAR16)(x1 * (VAR32)x>>(16-1));
	temp32 += (cSine4*(VAR32)x1)<<1;
	x1 = (VAR16)(x1 * (VAR32)x>>(16-1));
	temp32 += (cSine5*(VAR32)x1)<<1;
	temp32 <<= 3;

	if ((UVAR32)temp32 >= 0x7fffffff) {
		temp32 = 0x7fffffff;
	}
	if (theta <= 0) {
		temp32 *= (-1);
	}
	
	return ((VAR16)(temp32>>16));
}


/****************************************************************************************
 * Module   : E_Cosine
 *---------------------------------------------------------------------------------------
 * Function : 
 * Input    : theta
 * Output   : 
 * Note     : 
 ****************************************************************************************/
short	E_Cosine(short theta)
{
	return (E_Sine((short)(ELE_DEG(90) + theta)));
}


