/**************************************************
<> File Name	port_def.h
<> Content		I/O Port define of [SMC]M370 Board
<> Date			2009/06/XX
<> Group		TOSHIBA MICROELECTRONICS CORPORATION
<> Desine		
<> 쌠
<> ӎȂ
**************************************************/
#ifndef	_PORT_DEF_H
#define	_PORT_DEF_H
#include "sys_macro.h"

/*-------------------------------------------------------------------------------
			init_PnDT	Port input/output data register
			init_PnCR	Port control register   (0:input mode, 1:output mode)
			init_PnFR1	Switch port function 1  (0:Port, 1:Function1)
			init_PnFR2	Switch port function 2  (0:Port, 1:Function2)
			init_PnOD	Switch Open draine port (0:CMOS, 1:OD)
			init_PnPUP	Switch Pull-up port     (0:OFF, 1:ON)
			init_PnPDN	Switch Pull-down port   (0:OFF, 1:ON)
			init_PnIE	Input ebable			(0:disable, 1:Enable)
-------------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------------
PORT A
-------------------------------------------------------------------------------*/
/* bit0-3 output LCD data to LCD    */
/* bit4,5,7 output SIO CLK & DATA to DAC IC */
/* bit6 output monitor data for debug    */
#define		init_PADT	   BIT8(0,0,1,1,0,0,0,0)
#define		init_PACR	   BIT8(1,1,1,1,1,1,1,1)
#define		init_PAFR1	   BIT8(0,0,1,1,0,0,0,0)
#define		init_PAFR2	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PAOD	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PAPUP	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PAPDN	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PAIE	   BIT8(0,0,0,0,0,0,0,0)
						/* 0	| | | | | | | +--	Out P DB7	LCD disp data			*/
						/* 1	| | | | | | +----	Out P DB6	LCD disp data			*/
						/* 2	| | | | | +------	Out P DB5	LCD disp data			*/
						/* 3	| | | | +--------	Out P DB4	LCD disp data			*/
						/* 4	| | | +----------	Out SCK1	Clock to DAC or DBT		*/
						/* 5	| | +------------	Out TX1		TX data to DAC or DBT	*/
						/* 6	| +--------------	Out P ---	monitor out for Debug	*/
						/* 7	+----------------	Out P LDAC	LDAC of DAC				*/

/*-------------------------------------------------------------------------------
PORT B
-------------------------------------------------------------------------------*/
/* PB3~PB7 are debug function at reset */
/* PB3~PB7 is used JTAG, so keep the setting of reset condition */
#define		init_PBDT	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PBCR	   BIT8(0,0,1,0,1,0,0,0)
#define		init_PBFR1	   BIT8(1,1,1,1,1,0,0,0)
#define		init_PBOD	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PBPUP	   BIT8(1,1,0,0,1,0,0,0)
#define		init_PBPDN	   BIT8(0,0,0,1,0,0,0,0)
#define		init_PBIE	   BIT8(1,1,0,1,1,0,0,0)
						/* 0	| | | | | | | +--	PB0 Monitor out (TRACECLK)  */
						/* 1	| | | | | | +----	PB1 NC (TRACEDATA0)*/
						/* 2	| | | | | +------	PB2 NC (TRACEDATA1)*/
						/* 2	| | | | +--------	PB3 TMS/SWDIO      */
						/* 4	| | | +----------	PB4 TCK/SWCLK      */
						/* 5	| | +------------	PB5 TDO/SWV        */
						/* 6	| +--------------	PB6 TDI            */
						/* 7	+----------------	PB7 TRST           */

/*-------------------------------------------------------------------------------
PORT C
-------------------------------------------------------------------------------*/
/* PMD0 port --- PC0 */
/* When it use PMD, set PMD output function at first */
#define		init_PCDT	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PCCR	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PCFR1	   BIT8(0,0,0,0,0,0,0,0)	// PMD0 output Disable
#define		PMD0_PCFR1	   BIT8(0,0,1,1,1,1,1,1)	// PMD0 output Enable
#define		init_PCOD	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PCPUP	   BIT8(1,1,0,0,0,0,0,0)
#define		init_PCPDN	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PCIE	   BIT8(1,1,0,0,0,0,0,0)
						/* 0	| | | | | | | +--	PC0 U0 out	*/
						/* 1	| | | | | | +----	PC1 X0 out	*/
						/* 2	| | | | | +------	PC2 V0 out	*/
						/* 3	| | | | +--------	PC3 X0 out	*/
						/* 4	| | | +----------	PC4	W0 out	*/
						/* 5	| | +------------	PC5	Z0 out	*/
						/* 6	| +--------------	PC6	EMG0 in	*/
						/* 7	+----------------	PC7	OVV0 in	*/


/*-------------------------------------------------------------------------------
PORT D
-------------------------------------------------------------------------------*/
/* PD0~2 is used as encoder input   */
/* PD3,4 is used as LED out			*/
/* PD5,6 is used as USB driver IO   */
#define		init_PDDT	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PDCR	   BIT8(0,0,1,0,0,0,0,0)
#define		init_PDFR1	   BIT8(0,1,1,0,0,1,1,1)
#define		init_PDFR2	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PDOD	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PDPUP	   BIT8(0,1,0,0,0,0,0,0)
#define		init_PDPDN	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PDIE	   BIT8(0,1,0,1,1,1,1,1)
						/* 0	| | | | | | | +--	PD0 ENCA0 in			*/
						/* 1	| | | | | | +----	PD1 ENCB0 in			*/
						/* 2	| | | | | +------	PD2 ENCZ0 in 			*/
						/* 3	| | | | +--------	PD3 P --- LED24 out		*/
						/* 4	| | | +----------	PD4 P --- LED25 out		*/
						/* 5	| | +------------	PD5 TX2   USB Driver	*/
						/* 6	| +--------------	PD6 RX2   USB Driver	*/
						/* 7	+----------------	(PD7)					*/


/*-------------------------------------------------------------------------------
PORT E
-------------------------------------------------------------------------------*/
/* bit3   output control data to DAC IC */
/* bit4,5 output control data to LCD driver */
/* bit6,7 output to LED */
#define		init_PEDT	   BIT8(1,1,1,1,1,0,0,1)
#define		init_PECR	   BIT8(1,1,1,1,1,0,0,1)
#define		init_PEFR1	   BIT8(0,0,0,0,0,0,1,1)
#define		init_PEFR2	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PEOD	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PEPUP	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PEPDN	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PEIE	   BIT8(0,0,0,0,0,0,1,0)
						/* 0	| | | | | | | +--	PE0   TX0	to UART(232C)	*/
						/* 1	| | | | | | +----	PE1   RX0	to UART(232C)	*/
						/* 2	| | | | | +------	PE2 (no use)				*/
						/* 3	| | | | +--------	PE3 P ---	DAC /SYNC out	*/
						/* 4	| | | +----------	PE4 P ---	E of LCD DRV	*/
						/* 5	| | +------------	PE5 P ---   RS of LCD DRV	*/
						/* 6	| +--------------	PE6 P ---   LED22 out		*/
						/* 7	+----------------	PE7 P ---   LED23 out		*/


/*-------------------------------------------------------------------------------
PORT F
-------------------------------------------------------------------------------*/
/* PF2~PF4 is used as encoder input */
#define		init_PFDT	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFCR	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFFR1	   BIT8(0,0,0,1,1,1,0,0)
#define		init_PFFR2	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFFR3	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFOD	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFPUP	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFPDN	   BIT8(0,0,0,0,0,0,0,0)
#define		init_PFIE	   BIT8(0,0,0,1,1,1,0,0)
						/* 0	| | | | | | | +--	PF0 NC	(TB7IN)		*/
						/* 1	| | | | | | +----	PF1 NC	(TB7OUT)	*/
						/* 2	| | | | | +------	PF2 ENCA1 in		*/
						/* 3	| | | | +--------	PF3 ENCB1 in		*/
						/* 4	| | | +----------	PF4 ENCZ1 in		*/
						/* 5	| | +------------	(PF5)				*/
						/* 6	| +--------------	(PF6)				*/
						/* 7	+----------------	(PF7)				*/


/*-------------------------------------------------------------------------------
PORT G
-------------------------------------------------------------------------------*/
/* PMD1 port --- PG0 */
#define		init_PGDT		BIT8(0,0,0,0,0,0,0,0)
#define		init_PGCR		BIT8(0,0,0,0,0,0,0,0)
#define		init_PGFR1		BIT8(0,0,0,0,0,0,0,0)
#define		PMD1_PCFR1		BIT8(0,0,1,1,1,1,1,1)	// PMD1 output Enable
#define		init_PGOD		BIT8(0,0,0,0,0,0,0,0)
#define		init_PGPUP		BIT8(1,1,0,0,0,0,0,0)
#define		init_PGPDN		BIT8(0,0,0,0,0,0,0,0)
#define		init_PGIE		BIT8(1,1,0,0,0,0,0,0)
						/* 0	 | | | | | | | +--	PG0 U1 out	*/
						/* 1	 | | | | | | +----	PG1 X1 out	*/
						/* 2	 | | | | | +------	PG2 V1 out	*/
						/* 3	 | | | | +--------	PG3 X1 out	*/
						/* 4	 | | | +----------	PG4	W1 out	*/
						/* 5	 | | +------------	PG5	Z1 out	*/
						/* 6	 | +--------------	PG6	EMG1 in	*/
						/* 7	 +----------------	PG7	OVV1 in	*/

/*-------------------------------------------------------------------------------
PORT H
-------------------------------------------------------------------------------*/
/* PH4~PH7 input 8bit data of SW */
#define		init_PHDT		BIT8(0,0,0,0,0,0,0,0)
#define		init_PHCR		BIT8(0,0,0,0,0,0,0,0)
#define		init_PHFR1		BIT8(0,0,0,0,0,0,0,0)
//#define	init_PHFR2		BIT8(0,0,0,0,0,0,0,0)
#define		init_PHOD		BIT8(0,0,0,0,0,0,0,0)
#define		init_PHPUP		BIT8(1,1,1,1,0,0,0,0)
#define		init_PHPDN		BIT8(0,0,0,0,0,0,0,0)
#define		init_PHIE		BIT8(1,1,1,1,0,0,0,0)
						/* 0	| | | | | | | +--	PH0 NC				*/
						/* 1	| | | | | | +----	PH1 NC				*/
						/* 2	| | | | | +------	PH2 NC				*/
						/* 3	| | | | +--------	PH3 NC				*/
						/* 4	| | | +----------	PH4 P SW4 in		*/
						/* 5	| | +------------	PH5 P SW3 in		*/
						/* 6	| +--------------	PH6 P SW2 in		*/
						/* 7	+----------------	PH7 P SW1 in		*/


/*-------------------------------------------------------------------------------
PORT I    PI0~PI3 4bit
-------------------------------------------------------------------------------*/
/* PI0  TRG-SW4              */
/* PI1~3 ADC input           */

#define		init_PIDT		BIT8(0,0,0,0,0,0,0,0)
#define		init_PICR		BIT8(0,0,0,0,0,0,0,0)
//#define	init_PIFR1		BIT8(0,0,0,0,0,0,0,0)
//#define	init_PIFR2		BIT8(0,0,0,0,0,0,0,0)
#define		init_PIOD		BIT8(0,0,0,0,0,0,0,0)
#define		init_PIPUP		BIT8(0,0,0,0,0,0,0,0)
#define		init_PIPDN		BIT8(0,0,0,0,0,0,0,0)
#define		init_PIIE		BIT8(0,0,0,0,0,0,0,0)
						/* 0	| | | | | | | +--	PI0 AINA8  Vdc		*/
						/* 1	| | | | | | +----	PI1 AINA9  IU		*/
						/* 2	| | | | | +------	PI2 AINA10 IV		*/
						/* 3	| | | | +--------	PI3 AINA11 IW		*/
						/* 4	| | | +----------	(PI4)				*/
						/* 5	| | +------------	(PI5)				*/
						/* 6	| +--------------	(PI6)				*/
						/* 7	+----------------	(PI7)				*/


/*-------------------------------------------------------------------------------
PORT J    PJ0~PJ7 8bit
-------------------------------------------------------------------------------*/
/* PJ0 input 1shunt current      */
/* PJ1 input motor0 voltage      */
/* PJ2 input motor1 voltage      */
/* PJ3~6 input VR   */
#define		init_PJDT		BIT8(0,0,0,0,0,0,0,0)
#define		init_PJCR		BIT8(0,0,0,0,0,0,0,0)
#define		init_PJFR1		BIT8(0,0,0,0,0,0,0,0)
//#define	init_PJFR2		BIT8(0,0,0,0,0,0,0,0)
#define		init_PJOD		BIT8(0,0,0,0,0,0,0,0)
#define		init_PJPUP		BIT8(0,0,0,0,0,0,0,0)
#define		init_PJPDN		BIT8(0,0,0,0,0,0,0,0)
#define		init_PJIE		BIT8(0,0,0,0,0,0,0,0)
						/* 0	| | | | | | | +--	PJ0 AINB3 shunt U2	*/
						/* 1	| | | | | | +----	PJ1 AINB4 shunt V2	*/
						/* 2	| | | | | +------	PJ2 AINB5 shunt W2	*/
						/* 3	| | | | +--------	PJ3 AINB6 VR12 data	*/
						/* 4	| | | +----------	PJ4 AINB7 VR10 data	*/
						/* 5	| | +------------	PJ5 AINB8 VR9 data	*/
						/* 6	| +--------------	PJ6 AINB9 VR8 data	*/
						/* 7	+----------------	PJ7	NC (AINB10)		*/


/*-------------------------------------------------------------------------------
PORT K
-------------------------------------------------------------------------------*/
#define		init_PKDT		BIT8(0,0,0,0,0,0,0,0)
#define		init_PKCR		BIT8(0,0,0,0,0,0,0,0)
#define		init_PKFR1		BIT8(0,0,0,0,0,0,0,0)
//#define	init_PKFR2		BIT8(0,0,0,0,0,0,0,0)
#define		init_PKOD		BIT8(0,0,0,0,0,0,0,0)
#define		init_PKPUP		BIT8(0,0,0,0,0,0,0,0)
#define		init_PKPDN		BIT8(0,0,0,0,0,0,0,0)
#define		init_PKIE		BIT8(0,0,0,0,0,0,0,0)
						/* 0	| | | | | | | +--	PK0 NC		*/
						/* 1	| | | | | | +----	PK1 NC		*/
						/* 2	| | | | | +------	(PK2)		*/
						/* 3	| | | | +--------	(PK3)		*/
						/* 4	| | | +----------	(PK4)		*/
						/* 5	| | +------------	(PK5)		*/
						/* 6	| +--------------	(PK6)		*/
						/* 7	+----------------	(PK7)		*/

#endif	/* _PORT_DEF_H */

/*************************** END OF FILE **************************************/

